<?php
/**
 * Smart Wishlist Frontend
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.3.0
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WLFMC_Frontend' ) ) {
	/**
	 * This class handles frondend for wishlist plugin
	 */
	class WLFMC_Frontend {

		/**
		 * Single instance of the class
		 *
		 * @var WLFMC_Frontend
		 */
		protected static $instance;

		public $endpoint;

		/**
		 * Constructor
		 *
		 * @return void
		 * @version 1.3.0
		 */
		public function __construct() {

			// init widget
			add_action( 'widgets_init', array( $this, 'register_widget' ) );

			// init class.
			add_action( 'init', array( $this, 'init' ), 0 );

			// scripts.
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_styles_and_stuffs' ) );

			// templates.
			add_action( 'template_redirect', array( $this, 'add_nocache_headers' ) );
			add_action( 'wp_head', array( $this, 'add_noindex_header' ) );
			add_filter( 'wp_robots', array( $this, 'add_noindex_robots' ) );

			add_action( 'init', array( $this, 'add_button' ) );
			add_filter( 'body_class', array( $this, 'add_body_class' ) );

			// dashboard page.
			add_filter( 'woocommerce_account_menu_items', array( $this, 'dashboard_wishlist_link' ), 40 );
			add_action(
				'woocommerce_account_wlfmc-wishlist_endpoint',
				array(
					$this,
					'wlfmc_wishlist_endpoint_content',
				)
			);
			// Actions used to insert a new endpoint in the woocommerce.
			add_action( 'init', array( $this, 'add_endpoint' ) );
			add_filter( 'woocommerce_get_query_vars', array( $this, 'add_query_vars' ), 10 );
			add_filter( 'woocommerce_settings_pages', array( $this, 'add_endpoint_setting' ) );

			// Add wishlist counter to menu
			add_filter( 'wp_get_nav_menu_items', array( $this, 'prepare_menu' ), 9, 3 );
			add_filter( 'wp_nav_menu_items', array( $this, 'add_to_menu' ), 9, 2 );

			$this->endpoint = get_option( 'woocommerce_myaccount_wlfmc_wishlist_endpoint', 'wlfmc-wishlist' );
		}


		/**
		 * Prepare menu to add  wishlist counter
		 *
		 * @param array $items An array of menu item post objects.
		 * @param object $menu The menu object.
		 * @param array $args An array of arguments used to retrieve menu item objects.
		 *
		 * @return array
		 * @since 1.3.0
		 */
		public function prepare_menu( $items, $menu, $args ) {
			$options = new MCT_Options( 'wlfmc_options' );
			$menu_id = $options->get_option( 'counter_add_to_menu', '' );
			if ( '' !== $menu_id && $menu_id == $menu->term_id ) {
				$menu_cnt      = count( $items ) + 1;
				$menu_order    = $options->get_option( 'counter_menu_position', '100' );
				$menu_title    = is_admin() ? __( 'MC Wishlist Counter', 'wc-wlfmc-wishlist' ) : 'wlfmc-wishlist';
				$wishlist_item = (object) array(
					'ID'                    => $menu_cnt + 100000,
					'object_id'             => $menu_cnt + 100000,
					'db_id'                 => $menu_cnt + 100000,
					'title'                 => $menu_title,
					'post_title'            => $menu_title,
					'url'                   => '#' . $menu_title,
					'guid'                  => '#' . $menu_title,
					'post_date'             => gmdate( 'Y-m-d H:i:s' ),
					'post_date_gmt'         => gmdate( 'Y-m-d H:i:s' ),
					'post_modified'         => gmdate( 'Y-m-d H:i:s' ),
					'post_modified_gmt'     => gmdate( 'Y-m-d H:i:s' ),
					'menu_order'            => $menu_order,
					'menu_item_parent'      => 0,
					'type'                  => 'custom',
					'post_status'           => 'publish',
					'post_author'           => 1,
					'comment_status'        => 'closed',
					'ping_status'           => 'closed',
					'post_name'             => 'd',
					'post_parent'           => 0,
					'post_type'             => 'nav_menu_item',
					'comment_count'         => 0,
					'filter'                => 'raw',
					'object'                => 'custom',
					'type_label'            => '',
					'target'                => '',
					'attr_title'            => '',
					'classes'               => array(),
					'post_content'          => '',
					'post_excerpt'          => '',
					'category_post'         => '',
					'nolink'                => '',
					'description'           => '',
					'xfn'                   => '',
					'template'              => '',
					'mega_template'         => '',
					'megamenu'              => '',
					'megamenu_auto_width'   => '',
					'megamenu_col'          => '',
					'megamenu_heading'      => '',
					'megamenu_widgetarea'   => '',
					'icon'                  => '',
					'post_password'         => '',
					'to_ping'               => '',
					'pinged'                => '',
					'post_content_filtered' => '',
					'post_mime_type'        => '',
				);

				foreach ( array_keys( $items ) as $key ) {

					if ( $items[ $key ]->menu_order > ( $menu_order - 1 ) ) {
						$items[ $key ]->menu_order = $items[ $key ]->menu_order + 1;
					}
				}
				if ( $menu_order < $menu_cnt ) {
					array_splice( $items, $menu_order - 1, 0, array( $wishlist_item ) );
				} else {
					$items[] = $wishlist_item;
				}
			}

			return $items;
		}

		/**
		 * Add wishlist counter to menu
		 *
		 * @param $items
		 * @param $args
		 *
		 * @return array|mixed|string|string[]
		 * @since 1.3.0
		 */
		public function add_to_menu( $items, $args ) {

			if ( strpos( $items, 'href="#wlfmc-wishlist"' ) !== false ) {
				ob_start();
				echo do_shortcode( '[wlfmc_wishlist_counter]' );
				$content = ob_get_clean();
				preg_match( '/<a(.*?)href="#wlfmc-wishlist"(.*?)>wlfmc-wishlist<\/a>/', $items, $matches );
				if ( ! empty( $matches ) && '' !== $matches[0] ) {
					$items = str_replace( $matches[0], $content, $items );
				}
			}

			return $items;
		}

		/**
		 * Add editable endpoint to woocommerce settings pages.
		 *
		 * @param $settings
		 *
		 * @return array
		 * @since 1.2.2
		 */
		public function add_endpoint_setting( $settings ) {

			$settings = array_merge( array_slice( $settings, 0, count( $settings ) - 3, true ), array(
					array(
						'title'    => __( 'Wishlist', 'wc-wlfmc-wishlist' ),
						'desc'     => __( 'Endpoint for the "MC Wishlist" page.', 'wc-wlfmc-wishlist' ),
						'id'       => 'woocommerce_myaccount_wlfmc_wishlist_endpoint',
						'type'     => 'text',
						'default'  => 'wlfmc-wishlist',
						'desc_tip' => true,
					)
				)
				, array_slice( $settings, count( $settings ) - 3, 3, true ) );

			return $settings;
		}

		/**
		 * Initiator method.
		 *
		 * @return void
		 * @throws Exception Exception.
		 */
		public function init() {
			// update cookie from old version to new one.
			$this->_update_cookies();
			$this->_destroy_serialized_cookies();
			$this->_convert_cookies_to_session();

			// register assets.
			$this->register_styles_and_stuffs();
		}

		/**
		 * Add wishlist link to woocommerce dashboard.
		 *
		 * @param Array $menu_links array of menu links.
		 *
		 * @return array
		 */
		public function dashboard_wishlist_link( $menu_links ) {
			$menu_links = array_slice( $menu_links, 0, 1, true ) + array( $this->endpoint => __( 'Wishlist', 'wc-wlfmc-wishlist' ) ) + array_slice( $menu_links, 1, null, true );

			return $menu_links;
		}

		/**
		 * Add wishlist dashboard endpoint
		 *
		 * @return void
		 */
		public function add_endpoint() {

			add_rewrite_endpoint( $this->endpoint, EP_ROOT | EP_PAGES );

		}


		/**
		 * Add new query var.
		 *
		 * @param array $vars
		 *
		 * @return array
		 * @since 2.1.1
		 */
		public function add_query_vars( $vars ) {
			$vars['wlfmc-wishlist'] = $this->endpoint;

			return $vars;
		}


		/**
		 * Show wishlist in woocommerce dashboard
		 *
		 * @return void
		 */
		public function wlfmc_wishlist_endpoint_content() {

			echo do_shortcode( '[wlfmc_wishlist]' );
		}


		/**
		 * Add the "Add to Wishlist" button. Needed to use in wp_head hook.
		 *
		 * @return void
		 * @version 1.3.0
		 *
		 */
		public function add_button() {
			$positions = apply_filters(
				'wlfmc_button_positions',
				array(
					'before_add_to_cart'       => array(
						'hook'     => 'woocommerce_single_product_summary',
						'priority' => 29,
					),
					'after_add_to_cart'        => array(
						'hook'     => 'woocommerce_single_product_summary',
						'priority' => 31,
					),
					'after_add_to_cart_button' => array(
						'hook'     => 'woocommerce_after_add_to_cart_button',
						'priority' => 10,
					),

					'image_top_left'     => array(
						'hook'     => 'woocommerce_product_thumbnails',
						'priority' => 21,
					),
					'image_top_right'    => array(
						'hook'     => 'woocommerce_product_thumbnails',
						'priority' => 21,
					),
					'image_bottom_left'  => array(
						'hook'     => 'woocommerce_product_thumbnails',
						'priority' => 21,
					),
					'image_bottom_right' => array(
						'hook'     => 'woocommerce_product_thumbnails',
						'priority' => 21,
					),
					'summary'            => array(
						'hook'     => 'woocommerce_after_single_product_summary',
						'priority' => 11,
					),
				)
			);
			$options   = new MCT_Options( 'wlfmc_options' );

			$who_can_see_wishlist_options = $options->get_option( 'who_can_see_wishlist_options', 'all' );

			if ( ( 'users' === $who_can_see_wishlist_options && ! is_user_logged_in() ) ) {
				return;
			}
			// Add the link "Add to wishlist".
			$position = $options->get_option( 'wishlist_button_position', 'add-to-cart' );

			if ( 'shortcode' !== $position && isset( $positions[ $position ] ) ) {

				if ( isset( $positions[ $position ]['hook'] ) ) {
					add_action(
						$positions[ $position ]['hook'],
						array(
							$this,
							'print_button',
						),
						$positions[ $position ]['priority']
					);
				} else {
					foreach ( $positions[ $position ] as $hook ) {
						add_action(
							$hook['hook'],
							array(
								$this,
								'print_button',
							),
							$hook['priority']
						);
					}
				}

			}

			// check if Add to wishlist button is enabled for loop.
			$enabled_on_loop = true == $options->get_option( 'show_on_loop', true );

			if ( ! $enabled_on_loop ) {
				return;
			}

			$positions = apply_filters(
				'wlfmc_loop_positions',
				array(

					'image_top_left'     => array(
						'hook'     => 'woocommerce_before_shop_loop_item',
						'priority' => 21,
					),
					'image_top_right'    => array(
						'hook'     => 'woocommerce_before_shop_loop_item',
						'priority' => 21,
					),
					'before_add_to_cart' => array(
						'hook'     => 'woocommerce_after_shop_loop_item',
						'priority' => 7,
					),
					'after_add_to_cart'  => array(
						'hook'     => 'woocommerce_after_shop_loop_item',
						'priority' => 15,
					),
				)
			);

			// Add the link "Add to wishlist".
			$position = $options->get_option( 'loop_position', 'after_add_to_cart' );

			if ( 'shortcode' !== $position && isset( $positions[ $position ] ) ) {
				if ( isset( $positions[ $position ]['hook'] ) ) {
					add_action(
						$positions[ $position ]['hook'],
						array(
							$this,
							'print_button',
						),
						$positions[ $position ]['priority']
					);
				} else {
					foreach ( $positions[ $position ] as $hook ) {
						add_action(
							$hook['hook'],
							array(
								$this,
								'print_button',
							),
							$hook['priority']
						);
					}
				}
			}
		}


		/**
		 * Alter add to cart button when on wishlist page
		 *
		 * @return void
		 */
		public function alter_add_to_cart_button() {
			add_filter( 'woocommerce_product_add_to_cart_url', array( $this, 'alter_add_to_cart_url' ), 10, 2 );
		}

		/**
		 * Restore default Add to Cart button, after wishlist handling
		 *
		 * @return void
		 */
		public function restore_add_to_cart_button() {
			remove_filter( 'woocommerce_product_add_to_cart_url', array( $this, 'alter_add_to_cart_url' ) );
		}


		/**
		 * Filter Add to Cart button url on wishlist page
		 *
		 * @param string $url Url to the Add to Cart.
		 * @param WC_Product $product Current product.
		 *
		 * @return string Filtered url
		 * @version 1.3.1
		 */
		public function alter_add_to_cart_url( $url, $product ) {
			global $wlfmc_wishlist_token;

			if ( $wlfmc_wishlist_token ) {
				$wishlist = wlfmc_get_wishlist( $wlfmc_wishlist_token );

				if ( ! $wishlist ) {
					return $url;
				}

				$wishlist_id = $wishlist->get_id();
				$item        = $wishlist->get_product( $product->get_id() );
				$options     = new MCT_Options( 'wlfmc_options' );

				if ( wp_doing_ajax() ) {
					$wishlist_url = is_user_logged_in() ? apply_filters('wlfmc_user_logged_in_wishlist_url',wc_get_account_endpoint_url( $this->endpoint )) : WLFMC()->get_wishlist_url( 'view/' . $wlfmc_wishlist_token );
					$url          = add_query_arg( 'add-to-cart', $product->get_id(), $wishlist_url );
				}

				if ( $product->is_type( array(
						'simple',
						'variation'
					) ) && true == $options->get_option( 'redirect_after_add_to_cart', true ) ) {
					$url = add_query_arg( 'add-to-cart', $product->get_id(), wc_get_cart_url() );
				}

				if ( ! $product->is_type( 'external' ) && true == $options->get_option( 'remove_after_add_to_cart', true ) ) {
					$url = add_query_arg(
						array(
							'remove_from_wishlist_after_add_to_cart' => $product->get_id(),
							'wishlist_id'                            => $wishlist_id,
							'wishlist_token'                         => $wlfmc_wishlist_token,
						),
						$url
					);
				}

				if ( $item && true == apply_filters( 'wlfmc_quantity_show', true ) ) {
					$url = add_query_arg( 'quantity', $item->get_quantity(), $url );
				}
			}

			return apply_filters( 'wlfmc_add_to_cart_redirect_url', esc_url_raw( $url ), $url, $product );
		}


		/**
		 * Print "Add to Wishlist" shortcode
		 *
		 * @return void
		 */
		public function print_button() {
			/**
			 * Developers can use this filter to remove ATW button selectively from specific pages or products
			 * You can use global $product or $post to execute checks
			 */
			if ( ! apply_filters( 'wlfmc_show_add_to_wishlist', true ) ) {
				return;
			}

			echo do_shortcode( '[wlfmc_add_to_wishlist]' );
		}

		/**
		 * Add specific body class when the Wishlist page is opened
		 *
		 * @param array $classes Existing boy classes.
		 *
		 * @return array
		 */
		public function add_body_class( $classes ) {
			$wishlist_page_id = WLFMC()->get_wishlist_page_id();

			if ( ! empty( $wishlist_page_id ) && is_page( $wishlist_page_id ) ) {
				$classes[] = 'wlfmc-wishlist';
				$classes[] = 'woocommerce';
				$classes[] = 'woocommerce-page';
			}

			return $classes;
		}

		/**
		 * Send nocache headers on wishlist page
		 *
		 * @return void
		 */
		public function add_nocache_headers() {
			if ( ! headers_sent() && wlfmc_is_wishlist_page() ) {
				wc_nocache_headers();
			}
		}


		/**
		 * Send noindex header on Add To Wishlist url (?add_to_wishlist=12345)
		 * Deprecated since version 5.7 of WordPress.
		 *
		 * @return void
		 */
		public function add_noindex_header() {
			if ( function_exists( 'wp_robots_no_robots' ) || ! isset( $_GET['add_to_wishlist'] ) || apply_filters( 'wlfmc_skip_noindex_headers', false ) ) {// phpcs:ignore WordPress.Security.NonceVerification
				return;
			}

			wp_no_robots();
		}

		/**
		 * Disable search engines indexing for Add to Wishlist url.
		 * Uses "wp_robots" filter introduced in WP 5.7.
		 *
		 * @param array $robots Associative array of robots directives.
		 *
		 * @return array Filtered robots directives.
		 */
		public function add_noindex_robots( $robots ) {
			if ( ! isset( $_GET['add_to_wishlist'] ) || apply_filters( 'wlfmc_skip_noindex_headers', false ) ) {// phpcs:ignore WordPress.Security.NonceVerification
				return $robots;
			}

			return wp_robots_no_robots( $robots );
		}


		/**
		 * Register scripts and styles required by the plugin
		 *
		 * @return void
		 */
		public function register_styles_and_stuffs() {

			$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

			wp_register_style( 'wlfmc-main', MC_WLFMC_URL . 'assets/css/style' . $suffix . '.css', null, WLFMC_VERSION );

			wp_register_script( 'toastr', MC_WLFMC_URL . '/assets/js/toastr' . $suffix . '.js', array( 'jquery' ), WLFMC_VERSION, true );

			wp_register_script( 'jquery-popupoverlay', MC_WLFMC_URL . '/assets/js/jquery.popupoverlay' . $suffix . '.js', array( 'jquery' ), WLFMC_VERSION, true );

			wp_register_script( 'wlfmc-main', MC_WLFMC_URL . 'assets/js/scripts' . $suffix . '.js', array( 'jquery' ), WLFMC_VERSION, true );

			wp_localize_script( 'wlfmc-main', 'wlfmc_l10n', $this->get_localize() );

		}

		/**
		 * Enqueue styles, scripts and other stuffs needed in the <head>.
		 *
		 * @return void
		 */
		public function enqueue_styles_and_stuffs() {


			// main plugin style.
			wp_enqueue_style( 'wlfmc-main' );


			// custom style.
			$custom_css = $this->build_custom_css();

			if ( $custom_css ) {

				wp_add_inline_style( 'wlfmc-main', $custom_css );
			}

		}

		/**
		 * Enqueue plugin scripts.
		 *
		 * @return void
		 */
		public function enqueue_scripts() {
			wp_enqueue_script( 'toastr' );

			wp_enqueue_script( 'jquery-popupoverlay' );

			wp_enqueue_script( 'wlfmc-main' );
		}

		/**
		 * Return localize array
		 *
		 * @return array Array with variables to be localized inside js
		 *
		 * @version 1.0.1
		 */
		public function get_localize() {

			$options = new MCT_Options( 'wlfmc_options' );

			return apply_filters(
				'wlfmc_localize_script',
				array(
					'ajax_url'                               => admin_url( 'admin-ajax.php', 'relative' ),
					'redirect_to_cart'                       => $options->get_option( 'redirect_after_add_to_cart', true ),
					'multi_wishlist'                         => false,
					'ajax_loader_url'                        => MC_WLFMC_URL . 'assets/images/ajax-loader-alt.svg',
					'hide_add_button'                        => apply_filters( 'wlfmc_hide_add_button', true ),
					'remove_from_wishlist_after_add_to_cart' => $options->get_option( 'remove_after_add_to_cart', true ),
					'is_wishlist_responsive'                 => apply_filters( 'wlfmc_is_wishlist_responsive', true ),
					'fragments_index_glue'                   => apply_filters( 'wlfmc_fragments_index_glue', '.' ),
					'reload_on_found_variation'              => apply_filters( 'wlfmc_reload_on_found_variation', true ),
					'is_rtl'                                 => is_rtl(),
					'labels'                                 => array(
						'cookie_disabled'       => __( 'We are sorry, but this feature is available only if cookies on your browser are enabled.', 'wc-wlfmc-wishlist' ),
						'added_to_cart_message' => sprintf(
							'<div class="woocommerce-notices-wrapper"><div class="woocommerce-message" role="alert">%s</div></div>',
							apply_filters( 'wlfmc_added_to_cart_message', __( 'Product added to cart successfully', 'wc-wlfmc-wishlist' ) )
						),
						'login_need'            => apply_filters(
							'wlfmc_login_need_message',
							/* translators: %s: login url */
							sprintf( __( 'to use your Wishlist: %s', 'wc-wlfmc-wishlist' ), '<br><a href="' . esc_url( wp_login_url( wc_get_page_permalink( 'myaccount' ) ) ) . '" class="needlogin-btn">' . __( 'Login right now', 'wc-wlfmc-wishlist' ) . '</a>' )
						),
					),
					'actions'                                => array(
						'add_to_wishlist_action'      => 'wlfmc_add_to_wishlist',
						'remove_from_wishlist_action' => 'wlfmc_remove_from_wishlist',
						'delete_item_action'          => 'wlfmc_delete_item',
						'load_fragments'              => 'wlfmc_load_fragments',
						'update_item_quantity'        => 'wlfmc_update_item_quantity',
					),
				)
			);
		}

		/* === WIDGETS === */

		/**
		 * Registers widget used to show wishlist counter
		 *
		 * @return void
		 * @since 1.3.0
		 */
		public function register_widget() {
			register_widget( 'WLFMC_Counter_Widget' );
		}


		/* === UTILS === */

		/**
		 * Generate CSS codes to append to each page, to apply custom style to wishlist elements
		 *
		 * @param array $rules Array of additional rules to add to default ones.
		 *
		 * @return string Generated CSS code
		 *
		 * @version 1.3.1
		 */
		protected function build_custom_css( $rules = array() ) {
			$generated_code = '';
			$rules          = apply_filters(
				'wlfmc_custom_css_rules',
				array_merge(
					array(
						'popup_buttons'                        => array(
							'selector' => '.wlfmc-popup-footer .wlfmc_btn_%d',
							'rules'    => array(
								'background'        => array(
									'rule'    => 'background-color: %1$s;',
									'default' => 'transparent',
								),
								'background-hover'  => array(
									'rule'    => 'background-color: %1$s; ',
									'default' => 'transparent',
									'status'  => ':hover',
								),
								'label-color'       => array(
									'rule'    => 'color: %s',
									'default' => '#333',
								),
								'label-hover-color' => array(
									'rule'    => 'color: %s',
									'default' => '#ccc',
									'status'  => ':hover',
								),
								'border-radius'     => array(
									'rule'    => 'borer-radius: %s',
									'default' => '2px',
								),
							),
							'type'     => 'repeater',
						),
						'popup_background_color'               => array(
							'selector' => '.wlfmc-popup',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => 'transparent',
							),
						),
						'popup_border_color'                   => array(
							'selector' => '.wlfmc-popup',
							'rules'    => array(
								'rule'    => 'border-color: %s',
								'default' => '#e2e2e2',
							),
						),
						'popup_border_radius'                  => array(
							'selector' => '.wlfmc-popup',
							'rules'    => array(
								'rule'    => 'border-radius: %s',
								'default' => '8px',
							),
						),
						'icon_style_single'                    => array(
							'selector' => '.wlfmc-single-btn .wlfmc-add-button > a',
							'rules'    => array(
								'background'       => array(
									'rule'    => 'background-color: %1$s; ',
									'default' => 'transparent',
									'status'  => ' > i',
								),
								'background-hover' => array(
									'rule'    => 'background-color: %1$s;',
									'default' => 'transparent',
									'status'  => ':hover > i',
								),
								'color'            => array(
									'rule'    => 'color: %s',
									'default' => '#333',
									'status'  => ' > i',
								),
								'color-hover'      => array(
									'rule'    => 'color: %s',
									'default' => '#ccc',
									'status'  => ':hover > i',
								),
								/*'border'           => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#333',
									'status'  => ' > i',
								),
								'border-hover'     => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#ccc',
									'status'  => ':hover > i',
								),*/
							),
						),
						'text_style_single'                    => array(
							'selector' => '.wlfmc-single-btn .wlfmc-add-button > a',
							'rules'    => array(
								'background'       => array(
									'rule'    => 'background-color: %1$s !important; ',
									'default' => 'transparent',
								),
								'background-hover' => array(
									'rule'    => 'background-color: %1$s !important;',
									'default' => 'transparent',
									'status'  => ':hover',
								),
								'color'            => array(
									'rule'    => 'color: %s',
									'default' => '#333',
								),
								'color-hover'      => array(
									'rule'    => 'color: %s',
									'default' => '#ccc',
									'status'  => ':hover',
								),
								/*'border'           => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#333',
								),
								'border-hover'     => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#ccc',
									'status'  => ':hover',
								),*/
							),
						),
						'separator_color_single'               => array(
							'selector' => '.wlfmc-single-btn  .wlfmc-add-button > a.have-sep span',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => '#ccc',
								'status'  => ':before',
							),
						),
						'tooltip_color_single'                 => array(
							'selector' => ':root',
							'rules'    => array(
								'rule'    => '--tooltip-color-single: %s',
								'default' => '#fff',
							),
						),
						'tooltip_background_color_single'      => array(
							'selector' => ':root',
							'rules'    => array(
								'rule'    => '--tooltip-bg-single: %s',
								'default' => 'rgba(55, 64, 70, 0.9)',
							),
						),
						'tooltip_border_radius_single'         => array(
							'selector' => '.tooltiped-single',
							'rules'    => array(
								'rule'    => 'border-radius: %s',
								'default' => '6px',
								'status'  => ':before',
							),
						),
						'icon_font_size_single'                => array(
							'selector' => '.wlfmc-single-btn  .wlfmc-add-button > a i',
							'rules'    => array(
								'rule'    => 'font-size: %s',
								'default' => '14px',
							),
						),
						'text_font_size_single'                => array(
							'selector' => '.wlfmc-single-btn  .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'font-size: %s',
								'default' => '14px',
							),
						),
						'button_line_height_single'            => array(
							'selector' => '.wlfmc-single-btn  .wlfmc-add-button > a,.wlfmc-single-btn .wlfmc-add-button > a i',
							'rules'    => array(
								'rule'    => 'line-height: %s',
								'default' => 'inherit',
							),
						),
						'button_border_radius_single'          => array(
							'selector' => '.wlfmc-single-btn .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-radius: %s',
								'default' => '0',
							),
						),
						'button_border_width_single'          => array(
							'selector' => '.wlfmc-single-btn .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-width: %s',
								'default' => '0',
							),
						),
						'button_border_color_single'          => array(
							'selector' => '.wlfmc-single-btn .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-color: %s',
								'default' => 'transparent',
							),
						),
						'button_border_hover_color_single'          => array(
							'selector' => '.wlfmc-single-btn .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-color: %s',
								'default' => 'transparent',
								'status'  => ':hover',
							),
						),
						'button_margin_single'                 => array(
							'selector' => '.wlfmc-single-btn',
							'rules'    => array(
								'rule'    => 'margin: %s',
								'default' => '0',
							),
						),
						'icon_width_single'                    => array(
							'selector' => '.wlfmc-single-btn  .wlfmc-add-button > a i,.wlfmc-single-btn.wlfmc_btn_type_icon  .wlfmc-add-button > a ,.wlfmc-single-btn.wlfmc_top_of_image a',
							'rules'    => array(
								'rule'    => 'width: %s',
								'default' => 'auto',
							),
						),
						'button_height_single'                 => array(
							'selector' => '.wlfmc-single-btn  .wlfmc-add-button > a,.wlfmc-single-btn  .wlfmc-add-button > a i',
							'rules'    => array(
								'rule'    => 'height: %s',
								'default' => 'auto',
							),
						),
						'icon_style_loop'                      => array(
							'selector' => '.wlfmc-loop-btn .wlfmc-add-button > a',
							'rules'    => array(
								'background'       => array(
									'rule'    => 'background-color: %1$s;',
									'default' => 'transparent',
									'status'  => ' > i',
								),
								'background-hover' => array(
									'rule'    => 'background-color: %1$s;',
									'default' => 'transparent',
									'status'  => ':hover > i',
								),
								'color'            => array(
									'rule'    => 'color: %s',
									'default' => '#333',
									'status'  => ' > i',
								),
								'color-hover'      => array(
									'rule'    => 'color: %s',
									'default' => '#ccc',
									'status'  => ':hover > i',
								),
								/*'border'           => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#333',
									'status'  => ' > i',
								),
								'border-hover'     => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#ccc',
									'status'  => ':hover > i',
								),*/
							),
						),
						'text_style_loop'                      => array(
							'selector' => '.wlfmc-loop-btn .wlfmc-add-button > a',
							'rules'    => array(
								'background'       => array(
									'rule'    => 'background-color: %1$s; ',
									'default' => 'transparent',
								),
								'background-hover' => array(
									'rule'    => 'background-color: %1$s; ',
									'default' => 'transparent',
									'status'  => ':hover',
								),
								'color'            => array(
									'rule'    => 'color: %s',
									'default' => '#333',
								),
								'color-hover'      => array(
									'rule'    => 'color: %s',
									'default' => '#ccc',
									'status'  => ':hover',
								),
								/*'border'           => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#333',
								),
								'border-hover'     => array(
									'rule'    => 'box-shadow:inset 0 0 0 1px %s',
									'default' => '#ccc',
									'status'  => ':hover',
								),*/
							),
						),
						'separator_color_loop'                 => array(
							'selector' => '.wlfmc-loop-btn  .wlfmc-add-button > a.have-sep span',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => '#ccc',
								'status'  => ':before',
							),
						),
						'tooltip_color_loop'                   => array(
							'selector' => ':root',
							'rules'    => array(
								'rule'    => '--tooltip-color-loop: %s',
								'default' => '#fff',
							),
						),
						'tooltip_background_color_loop'        => array(
							'selector' => ':root',
							'rules'    => array(
								'rule'    => '--tooltip-bg-loop: %s',
								'default' => 'rgba(55, 64, 70, 0.9)',
							),
						),
						'tooltip_border_radius_loop'           => array(
							'selector' => '.tooltiped-loop',
							'rules'    => array(
								'rule'    => 'border-radius: %s',
								'default' => '6px',
								'status'  => ':before',
							),
						),
						'icon_font_size_loop'                  => array(
							'selector' => '.wlfmc-loop-btn  .wlfmc-add-button > a i',
							'rules'    => array(
								'rule'    => 'font-size: %s',
								'default' => '14px',
							),

						),
						'text_font_size_loop'                  => array(
							'selector' => '.wlfmc-loop-btn  .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'font-size: %s',
								'default' => '14px',
							),
						),
						'button_line_height_loop'              => array(
							'selector' => ' .wlfmc-loop-btn  .wlfmc-add-button > a,.wlfmc-loop-btn  .wlfmc-add-button > a i',
							'rules'    => array(
								'rule'    => 'line-height: %s',
								'default' => 'inherit',
							),
						),
						'icon_width_loop'                      => array(
							'selector' => '.wlfmc-loop-btn  .wlfmc-add-button > a i, .wlfmc-loop-btn.wlfmc_btn_type_icon  .wlfmc-add-button > a ',
							'rules'    => array(
								'rule'    => 'width: %s',
								'default' => 'auto',
							),
						),
						'button_height_loop'                   => array(
							'selector' => '.wlfmc-loop-btn .wlfmc-add-button > a, .wlfmc-loop-btn  .wlfmc-add-button > a i',
							'rules'    => array(
								'rule'    => 'height: %s',
								'default' => 'auto',
							),
						),
						'button_border_radius_loop'            => array(
							'selector' => '.wlfmc-loop-btn  .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-radius: %s',
								'default' => '0',
							),
						),
						'button_border_width_loop'          => array(
							'selector' => '.wlfmc-loop-btn .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-width: %s',
								'default' => '0',
							),
						),
						'button_border_color_loop'          => array(
							'selector' => '.wlfmc-loop-btn .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-color: %s',
								'default' => 'transparent',
							),
						),
						'button_border_hover_color_loop'          => array(
							'selector' => '.wlfmc-loop-btn .wlfmc-add-button > a',
							'rules'    => array(
								'rule'    => 'border-color: %s',
								'default' => 'transparent',
								'status'  => ':hover',
							),
						),
						'button_margin_loop'                   => array(
							'selector' => '.wlfmc-loop-btn',
							'rules'    => array(
								'rule'    => 'margin: %s',
								'default' => '0',
							),
						),
						'login_notice_background_color'        => array(
							'selector' => '.wlfmc_guest_notice_wrapper',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => 'transparent',
							),
						),
						'login_notice_buttons'                 => array(
							'selector' => '.wlfmc_guest_notice_buttons .wlfmc_btn_%d',
							'rules'    => array(
								'background'        => array(
									'rule'    => 'background-color: %1$s !important; ',
									'default' => 'transparent',
								),
								'background-hover'  => array(
									'rule'    => 'background-color: %1$s  !important; ',
									'default' => 'transparent',
									'status'  => ':hover',
								),
								'label-color'       => array(
									'rule'    => 'color: %s  !important',
									'default' => '#333',
								),
								'label-hover-color' => array(
									'rule'    => 'color: %s  !important',
									'default' => '#ccc',
									'status'  => ':hover',
								),
								'border-radius'     => array(
									'rule'    => 'borer-radius: %s',
									'default' => '2px',
								),
							),
							'type'     => 'repeater',
						),
						'wishlist_button_style'                => array(
							'selector' => '.wlfmc_wishlist_table tr td.last-column input.qty, .wlfmc_wishlist_table tr td.last-column .button, .wlfmc_wishlist_footer .button, .wlfmc_wishlist_footer button[type="submit"], .wlfmc_wishlist_footer input[type="submit"], .wlfmc_wishlist_footer select,.wlfmc_wishlist_footer select option',
							'rules'    => array(
								'background'       => array(
									'rule'    => 'background-color: %1$s !important; ',
									'default' => '#ebebeb',
								),
								'background-hover' => array(
									'rule'    => 'background-color: %1$s !important; ',
									'default' => '#e67e22',
									'status'  => ':hover',
								),
								'color'            => array(
									'rule'    => 'color: %s !important',
									'default' => '#515151',
								),
								'color-hover'      => array(
									'rule'    => 'color: %s !important',
									'default' => '#fff',
									'status'  => ':hover',
								),
								'border'           => array(
									'rule'    => 'border-color: %s !important',
									'default' => 'transparent',
								),
								'border-hover'     => array(
									'rule'    => 'border-color: %s !important',
									'default' => 'transparent',
									'status'  => ':hover',
								),
							),
						),
						'wishlist_button_height'               => array(
							'selector' => '.wlfmc_wishlist_table tr td.last-column input.qty,.wlfmc_wishlist_table tr td.last-column .button, .wlfmc_wishlist_footer .button, .wlfmc_wishlist_footer button[type="submit"], .wlfmc_wishlist_footer input[type="submit"], .wlfmc_wishlist_footer select',
							'rules'    => array(
								'rule'    => 'height: %s',
								'default' => '38px',
							),
						),
						'wishlist_button_line_height'          => array(
							'selector' => '.wlfmc_wishlist_table tr td.last-column input.qty,.wlfmc_wishlist_table tr td.last-column .button, .wlfmc_wishlist_footer .button, .wlfmc_wishlist_footer button[type="submit"], .wlfmc_wishlist_footer input[type="submit"], .wlfmc_wishlist_footer select',
							'rules'    => array(
								'rule'    => 'line-height: %s',
								'default' => '28px',
							),
						),
						'wishlist_button_border_radius'        => array(
							'selector' => '.wlfmc_wishlist_table tr td.last-column input.qty,.wlfmc_wishlist_table tr td.last-column .button, .wlfmc_wishlist_footer .button, .wlfmc_wishlist_footer button[type="submit"], .wlfmc_wishlist_footer input[type="submit"], .wlfmc_wishlist_footer select',
							'rules'    => array(
								'rule'    => 'border-radius: %s !important',
								'default' => '0',
							),
						),
						'wishlist_table_thumbnail_background'  => array(
							'selector' => '.wlfmc_wishlist_table .product-thumbnail img',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => '#f5f5f5',
							),
						),
						'wishlist_table_grid_border_color'     => array(
							'selector' => '.wlfmc_wishlist_table.view_mode_grid .wishlist-items-wrapper tr',
							'rules'    => array(
								'rule'    => 'border-color: %s !important',
								'default' => '#ebebeb',
							),
						),
						'wishlist_table_grid_border_radius'    => array(
							'selector' => '.wlfmc_wishlist_table.view_mode_grid .wishlist-items-wrapper tr',
							'rules'    => array(
								'rule'    => 'border-radius: %s !important',
								'default' => '10px',
							),
						),
						'wishlist_table_item_background'       => array(
							'selector' => '.wlfmc_wishlist_table .wishlist-items-wrapper tr',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => 'transparent',
							),
						),
						'wishlist_table_item_hover_background' => array(
							'selector' => '.wlfmc_wishlist_table .wishlist-items-wrapper tr',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => 'transparent',
								'status'  => ':hover',
							),
						),
						'wishlist_table_separator_color'       => array(
							'selector' => '.wlfmc_wishlist_table td.with-border-top',
							'rules'    => array(
								'rule'    => 'border-top-color: %s !important',
								'default' => '#ebebeb',
							),
						),
						'social_color'                         => array(
							'selector' => '.wlfmc_wishlist_footer .share-wrapper a ',
							'rules'    => array(
								'rule'    => 'color: %s',
								'default' => '#9c9c9c',
							),
						),
						'social_hover_color'                   => array(
							'selector' => '.wlfmc_wishlist_footer .share-wrapper a ',
							'rules'    => array(
								'rule'    => 'color: %s',
								'default' => '#515151',
								'status'  => ':hover',
							),
						),
						'counter_button_style'                 => array(
							'selector' => '.wlfmc_products_counter_wrapper .button',
							'rules'    => array(
								'background'       => array(
									'rule'    => 'background-color: %1$s !important; ',
									'default' => '#ebebeb',
								),
								'background-hover' => array(
									'rule'    => 'background-color: %1$s !important; ',
									'default' => '#e67e22',
									'status'  => ':hover',
								),
								'color'            => array(
									'rule'    => 'color: %s !important',
									'default' => '#515151',
								),
								'color-hover'      => array(
									'rule'    => 'color: %s !important',
									'default' => '#fff',
									'status'  => ':hover',
								),
								'border'           => array(
									'rule'    => 'border-color: %s !important',
									'default' => 'transparent',
								),
								'border-hover'     => array(
									'rule'    => 'border-color: %s !important',
									'default' => 'transparent',
									'status'  => ':hover',
								),
							),
						),
						'counter_color'                        => array(
							'selector' => '.wlfmc_products_counter_wrapper .wlfmc_counter_icon i.wlfmc-svg',
							'rules'    => array(
								'rule'    => 'color: %s',
								'default' => '#333',
							),
						),
						'counter_icon_width'                      => array(
							'selector' => '.wlfmc_products_counter_wrapper .wlfmc_counter_icon i.wlfmc-svg',
							'rules'    => array(
								'rule'    => 'width: %s',
								'default' => '24px',
							),
						),
						'counter_text_color'                   => array(
							'selector' => '.wlfmc_products_counter_wrapper .wlfmc_products_counter',
							'rules'    => array(
								'rule'    => 'color: %s',
								'default' => '#333',
							),
						),
						'counter_background_color'             => array(
							'selector' => '.wlfmc_products_counter_wrapper .wlfmc_products_counter_wishlist',
							'rules'    => array(
								'rule'    => 'background-color: %s',
								'default' => '#fff',
							),
						),
						'counter_border_color'                 => array(
							'selector' => '.wlfmc_products_counter_wrapper .wlfmc_products_counter_wishlist',
							'rules'    => array(
								'rule'    => 'border-color: %s !important',
								'default' => '#f5f5f5',
							),
						),
						'counter_border_radius'                => array(
							'selector' => '.wlfmc_products_counter_wrapper .wlfmc_products_counter_wishlist',
							'rules'    => array(
								'rule'    => 'border-radius: %s !important',
								'default' => '5px',
							),
						),
						'counter_button_border_radius'         => array(
							'selector' => '.wlfmc_products_counter_wrapper .button',
							'rules'    => array(
								'rule'    => 'border-radius: %s !important',
								'default' => '10px',
							),
						),

					),
					$rules
				)
			);

			if ( empty( $rules ) ) {
				return $generated_code;
			}
			$options                        = new MCT_Options( 'wlfmc_options' );
			$button_theme_single            = $options->get_option( 'button_theme_single', true );
			$button_theme_loop              = $options->get_option( 'button_theme_loop', true );
			$button_type_single             = $options->get_option( 'button_type_single', 'icon' );
			$button_type_loop               = $options->get_option( 'button_type_loop', 'icon' );
			$wishlist_custom_template       = $options->get_option( 'wishlist_custom_template', true );
			$click_wishlist_button_behavior = $options->get_option( 'click_wishlist_button_behavior', 'just-add' );

			if ( true == $button_theme_single ) {
				if ( isset( $rules['icon_width_single'] ) ) {
					unset( $rules['icon_width_single'] );
				}
				if ( isset( $rules['button_margin_single'] ) ) {
					unset( $rules['button_margin_single'] );
				}

				if ( isset( $rules['button_height_single'] ) ) {
					unset( $rules['button_height_single'] );
				}
				if ( isset( $rules['button_line_height_single'] ) ) {
					unset( $rules['button_line_height_single'] );
				}
				if ( isset( $rules['button_border_radius_single'] ) ) {
					unset( $rules['button_border_radius_single'] );
				}

				if ( isset( $rules['button_border_width_single'] ) ) {
					unset( $rules['button_border_width_single'] );
				}

				if ( isset( $rules['button_border_color_single'] ) ) {
					unset( $rules['button_border_color_single'] );
				}

				if ( isset( $rules['button_border_hover_color_single'] ) ) {
					unset( $rules['button_border_hover_color_single'] );
				}

				if ( isset( $rules['icon_style_single'] ) ) {
					unset( $rules['icon_style_single'] );
				}
				if ( isset( $rules['text_style_single'] ) ) {
					unset( $rules['text_style_single'] );
				}
				if ( isset( $rules['text_font_size_single'] ) ) {
					unset( $rules['text_font_size_single'] );
				}
				if ( isset( $rules['icon_font_size_single'] ) ) {
					unset( $rules['icon_font_size_single'] );
				}
			}
			if ( true == $button_theme_loop ) {
				if ( isset( $rules['icon_width_loop'] ) ) {
					unset( $rules['icon_width_loop'] );
				}
				if ( isset( $rules['button_margin_loop'] ) ) {
					unset( $rules['button_margin_loop'] );
				}

				if ( isset( $rules['button_height_loop'] ) ) {
					unset( $rules['button_height_loop'] );
				}
				if ( isset( $rules['button_line_height_loop'] ) ) {
					unset( $rules['button_line_height_loop'] );
				}
				if ( isset( $rules['button_border_radius_loop'] ) ) {
					unset( $rules['button_border_radius_loop'] );
				}

				if ( isset( $rules['button_border_width_loop'] ) ) {
					unset( $rules['button_border_width_loop'] );
				}

				if ( isset( $rules['button_border_color_loop'] ) ) {
					unset( $rules['button_border_color_loop'] );
				}

				if ( isset( $rules['button_border_hover_color_loop'] ) ) {
					unset( $rules['button_border_hover_color_loop'] );
				}

				if ( isset( $rules['icon_style_loop'] ) ) {
					unset( $rules['icon_style_loop'] );
				}
				if ( isset( $rules['text_style_loop'] ) ) {
					unset( $rules['text_style_loop'] );
				}
				if ( isset( $rules['text_font_size_loop'] ) ) {
					unset( $rules['text_font_size_loop'] );
				}
				if ( isset( $rules['icon_font_size_loop'] ) ) {
					unset( $rules['icon_font_size_loop'] );
				}
			}
			if ( true == $wishlist_custom_template ) {

				if ( isset( $rules['wishlist_button_style'] ) ) {
					unset( $rules['wishlist_button_style'] );
				}
				if ( isset( $rules['wishlist_button_height'] ) ) {
					unset( $rules['wishlist_button_height'] );
				}
				if ( isset( $rules['wishlist_button_line_height'] ) ) {
					unset( $rules['wishlist_button_line_height'] );
				}
				if ( isset( $rules['wishlist_button_border_radius'] ) ) {
					unset( $rules['wishlist_button_border_radius'] );
				}

				if ( isset( $rules['wishlist_table_thumbnail_background'] ) ) {
					unset( $rules['wishlist_table_thumbnail_background'] );
				}
				if ( isset( $rules['wishlist_table_grid_border_color'] ) ) {
					unset( $rules['wishlist_table_grid_border_color'] );
				}
				if ( isset( $rules['wishlist_table_grid_border_radius'] ) ) {
					unset( $rules['wishlist_table_grid_border_radius'] );
				}
				/*if ( isset( $rules['wishlist_table_list_border_color'] ) ) {
					unset( $rules['wishlist_table_list_border_color'] );
				}
				if ( isset( $rules['wishlist_table_list_border_radius'] ) ) {
					unset( $rules['wishlist_table_list_border_radius'] );
				}*/
				if ( isset( $rules['wishlist_table_item_background'] ) ) {
					unset( $rules['wishlist_table_item_background'] );
				}
				if ( isset( $rules['wishlist_table_item_hover_background'] ) ) {
					unset( $rules['wishlist_table_item_hover_background'] );
				}
				if ( isset( $rules['wishlist_table_separator_color'] ) ) {
					unset( $rules['wishlist_table_separator_color'] );
				}
			}

			if ( 'icon' == $button_type_single ) {

				if ( isset( $rules['text_style_single'] ) ) {
					unset( $rules['text_style_single'] );
				}
			}
			if ( 'text' == $button_type_single ) {
				if ( isset( $rules['icon_style_single'] ) ) {
					unset( $rules['icon_style_single'] );
				}
			}
			if ( 'both' == $button_type_single && false == $options->get_option( 'separate_icon_and_text_single', false ) ) {
				if ( isset( $rules['separator_color_single'] ) ) {
					unset( $rules['separator_color_single'] );
				}
			}
			if ( 'icon' == $button_type_loop ) {

				if ( isset( $rules['text_style_loop'] ) ) {
					unset( $rules['text_style_loop'] );
				}
			}
			if ( 'text' == $button_type_loop ) {
				if ( isset( $rules['icon_style_loop'] ) ) {
					unset( $rules['icon_style_loop'] );
				}
			}
			if ( 'both' == $button_type_loop && false == $options->get_option( 'separate_icon_and_text_loop', false ) ) {
				if ( isset( $rules['separator_color_loop'] ) ) {
					unset( $rules['separator_color_loop'] );
				}
			}

			if ( false == $options->get_option( 'enable_tooltip_single', false ) ) {
				if ( isset( $rules['tooltip_color_single'] ) ) {
					unset( $rules['tooltip_color_single'] );
				}
				if ( isset( $rules['tooltip_background_color_single'] ) ) {
					unset( $rules['tooltip_background_color_single'] );
				}
				if ( isset( $rules['tooltip_border_radius_single'] ) ) {
					unset( $rules['tooltip_border_radius_single'] );
				}
			}
			if ( false == $options->get_option( 'enable_tooltip_loop', false ) ) {
				if ( isset( $rules['tooltip_color_loop'] ) ) {
					unset( $rules['tooltip_color_loop'] );
				}
				if ( isset( $rules['tooltip_background_color_loop'] ) ) {
					unset( $rules['tooltip_background_color_loop'] );
				}
				if ( isset( $rules['tooltip_border_radius_loop'] ) ) {
					unset( $rules['tooltip_border_radius_loop'] );
				}
			}
			if ( 'open-popup' != $click_wishlist_button_behavior ) {
				if ( isset( $rules['popup_buttons'] ) ) {
					unset( $rules['popup_buttons'] );
				}
				if ( isset( $rules['popup_background_color'] ) ) {
					unset( $rules['popup_background_color'] );
				}
				if ( isset( $rules['popup_border_color'] ) ) {
					unset( $rules['popup_border_color'] );
				}
				if ( isset( $rules['popup_border_radius'] ) ) {
					unset( $rules['popup_border_radius'] );
				}
			}

			if ( false == $options->get_option( 'show_login_notice_for_guests', true ) ) {
				if ( isset( $rules['login_notice_background_color'] ) ) {
					unset( $rules['login_notice_background_color'] );
				}
				if ( isset( $rules['login_notice_buttons'] ) ) {
					unset( $rules['login_notice_buttons'] );
				}
			}

			foreach ( $rules as $id => $rule ) {

				// retrieve values from db.
				$values     = $options->get_option( $id );
				$new_rules  = array();
				$rules_code = '';

				if ( isset( $rule['rules']['rule'] ) ) {
					// if we have a single-valued option, just search for the rule to apply.
					$status = isset( $rule['rules']['status'] ) ? $rule['rules']['status'] : '';


					$new_rules[ $status ]   = array();
					$new_rules[ $status ][] = $this->build_css_rule( $rule['rules']['rule'], $values, $rule['rules']['default'] );
				} elseif ( isset( $rule['type'] ) && 'repeater' === $rule['type'] ) {
					// if we have a repeater field cycle through rules, and generate CSS code.
					if ( is_array( $values ) && ! empty( $values ) ) {
						foreach ( $values as $k => $row ) {
							foreach ( $rule['rules'] as $property => $css ) {
								$status = isset( $css['status'] ) ? $css['status'] : '';

								if ( ! isset( $new_rules[ $status ] ) ) {
									$new_rules[ $status ] = array();
								}

								$new_rules[ $k ][ $status ][] = $this->build_css_rule( $css['rule'], isset( $row[ $property ] ) ? $row[ $property ] : false, $css['default'] );
							}
						}
					}
				} else {
					// otherwise, cycle through rules, and generate CSS code.
					foreach ( $rule['rules'] as $property => $css ) {
						$status = isset( $css['status'] ) ? $css['status'] : '';

						if ( ! isset( $new_rules[ $status ] ) ) {
							$new_rules[ $status ] = array();
						}

						$new_rules[ $status ][] = $this->build_css_rule( $css['rule'], isset( $values[ $property ] ) ? $values[ $property ] : false, $css['default'] );
					}
				}


				// if code was generated, prepend selector.
				if ( ! empty( $new_rules ) ) {
					if ( isset( $rule['type'] ) && 'repeater' === $rule['type'] ) {
						foreach ( $new_rules as $k => $row ) {

							$selector = sprintf( $rule['selector'], $k );
							foreach ( $row as $status => $rules ) {
								//$selector = $rule['selector'];
								if ( ! empty( $status ) ) {
									$updated_selector = array();
									$split_selectors  = explode( ',', $selector );

									foreach ( $split_selectors as $split_selector ) {
										$updated_selector[] = $split_selector . $status;
									}

									$selector = implode( ',', $updated_selector );
								}

								$rules_code .= $selector . '{' . implode( '', $rules ) . '}';
							}
						}
					} else {
						foreach ( $new_rules as $status => $rules ) {
							$selector = $rule['selector'];

							if ( ! empty( $status ) ) {
								$updated_selector = array();
								$split_selectors  = explode( ',', $rule['selector'] );

								foreach ( $split_selectors as $split_selector ) {
									$updated_selector[] = $split_selector . $status;
								}

								$selector = implode( ',', $updated_selector );
							}

							$rules_code .= $selector . '{' . implode( '', $rules ) . '}';
						}
					}
				}

				// append new rule to generated CSS.
				$generated_code .= $rules_code;
			}

			return $generated_code;
		}

		/**
		 * Generate each single CSS rule that will be included in custom plugin CSS
		 *
		 * @param string $rule Rule to use; placeholders may be applied to be replaced with value {@see sprintf}.
		 * @param string $value Value to inject inside rule, replacing placeholders.
		 * @param string $default Default value, to be used instead of value when it is empty.
		 *
		 * @return string Formatted CSS rule
		 */
		protected function build_css_rule( $rule, $value, $default = '' ) {
			$value = ( '0' === $value || ( ! empty( $value ) && ! is_array( $value ) ) ) ? $value : $default;

			return sprintf( rtrim( $rule, ';' ) . ';', $value );
		}

		/**
		 * Format options that will send through AJAX calls to refresh arguments
		 *
		 * @param array $options Array of options.
		 * @param string $context Widget/Shortcode that will use the options.
		 *
		 * @return array Array of formatted options
		 * @version 1.3.0
		 */
		public function format_fragment_options( $options, $context = '' ) {
			// removes unusable values, and changes options common for all fragments.
			if ( ! empty( $options ) ) {
				foreach ( $options as $id => $value ) {
					if ( is_object( $value ) || is_array( $value ) ) {
						// remove item if type is not supported.
						unset( $options[ $id ] );
					} elseif ( 'ajax_loading' === $id ) {
						$options['ajax_loading'] = false;
					}
				}
			}

			// applies context specific changes.
			if ( ! empty( $context ) ) {
				$options['item'] = $context;

				if ( $context == 'add_to_wishlist' ) {
					unset( $options['template_part'] );
					unset( $options['tooltip_label'] );
					unset( $options['label'] );
					unset( $options['exists'] );
					unset( $options['icon'] );
					unset( $options['link_classes'] );
					unset( $options['link_popup_classes'] );
					unset( $options['container_classes'] );
					unset( $options['found_in_list'] );
					unset( $options['found_item'] );
					unset( $options['popup_title'] );
					unset( $options['wishlist_url'] );
				}
			}

			return $options;
		}

		/**
		 * Decode options that come from the fragment
		 *
		 * @param array $options Options for the fragments.
		 *
		 * @return array Filtered options for the fragment
		 * @version 1.2.0
		 */
		public function decode_fragment_options( $options ) {
			if ( ! empty( $options ) ) {
				foreach ( $options as $id => $value ) {
					if ( 'true' == $value ) {
						$options[ $id ] = true;
					} elseif ( 'false' == $value ) {
						$options[ $id ] = false;
					} else {
						$options[ $id ] = wp_kses_post( wp_unslash( $value ) );
					}
				}
			}

			return $options;
		}


		/**
		 * Destroy serialize cookies, to prevent major vulnerability
		 *
		 * @return void
		 */
		protected function _destroy_serialized_cookies() {
			$name = 'wlfmc_products';

			if ( isset( $_COOKIE[ $name ] ) && is_serialized( stripslashes( $_COOKIE[ $name ] ) ) ) {
				$_COOKIE[ $name ] = wp_json_encode( array() );
				wlfmc_destroycookie( $name );
			}
		}

		/**
		 * Update old wishlist cookies
		 *
		 * @return void
		 */
		protected function _update_cookies() {
			$cookie     = wlfmc_getcookie( 'wlfmc_products' );
			$new_cookie = array();

			if ( ! empty( $cookie ) ) {
				foreach ( $cookie as $item ) {
					if ( ! isset( $item['add-to-wishlist'] ) ) {
						return;
					}

					$new_cookie[] = array(
						'prod_id'     => $item['add-to-wishlist'],
						'quantity'    => isset( $item['quantity'] ) ? $item['quantity'] : 1,
						'wishlist_id' => false,
					);
				}

				wlfmc_setcookie( 'wlfmc_products', $new_cookie );
			}
		}

		/**
		 * Convert wishlist stored into cookies into.
		 *
		 * @return bool|void
		 * @throws Exception  When not able to load default wishlist or Data Store class.
		 */
		protected function _convert_cookies_to_session() {
			$cookie = wlfmc_getcookie( 'wlfmc_products' );

			if ( ! empty( $cookie ) ) {

				$default_list = WLFMC_Wishlist_Factory::get_default_wishlist();

				if ( ! $default_list ) {
					return false;
				}

				foreach ( $cookie as $item ) {
					if ( $default_list->has_product( $item['prod_id'] ) ) {
						continue;
					}

					$new_item = new WLFMC_Wishlist_Item();

					$new_item->set_product_id( $item['prod_id'] );
					$new_item->set_quantity( $item['quantity'] );

					if ( isset( $item['dateadded'] ) ) {
						$new_item->set_date_added( $item['dateadded'] );
					}

					$default_list->add_item( $new_item );
				}

				$default_list->save();

				wlfmc_destroycookie( 'wlfmc_products' );
			}
		}

		/**
		 * Returns single instance of the class
		 *
		 * @return WLFMC_Frontend
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}
	}
}

/**
 * Unique access to instance of WLFMC_Frontend class
 *
 * @return WLFMC_Frontend
 */
function WLFMC_Frontend() {
	return WLFMC_Frontend::get_instance();
}
