<?php
/**
 * Offer emails class
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


if ( ! class_exists( 'WLFMC_Offer_Emails' ) ) {
	/**
	 * WooCommerce Wishlist Offer Emails
	 *
	 */
	class WLFMC_Offer_Emails extends WLFMC_Offer_Email {
		/**
		 * Single instance of the class
		 *
		 * @var WLFMC_Offer_Emails
		 */
		protected static $instance;

		/**
		 * Constructor method, used to return object of the class to WC
		 */
		public function __construct() {
			parent::__construct();
			add_action( 'wlfmc_added_to_wishlist', array( $this, 'add_emails' ), 10, 3 );
			add_action( 'wlfmc_send_offer_mail', array( $this, 'send_email' ), 10 );
			add_action( 'mc_panel_before_wlfmc_options_update', array( $this, 'check_for_delete_queue' ), 10 );
			add_action( 'woocommerce_payment_complete', array( $this, 'check_coupon_used' ), 10 );
		}

		/**
		 * add queue email to DB
		 *
		 * @param $prod_id
		 * @param $wishlist_id
		 * @param $user_id
		 *
		 * @version 1.0.1
		 */
		public function add_emails( $prod_id, $wishlist_id, $user_id ) {

			if ( ! is_user_logged_in() ) {
				return;
			}

			$wishlist = wlfmc_get_wishlist( $wishlist_id );

			if ( ! $wishlist ) {
				return;
			}

			$options            = new MCT_Options( 'wlfmc_options' );
			$min_total          = $options->get_option( 'minimum-wishlist-total', 1 );
			$min_count          = $options->get_option( 'minimum-wishlist-count', 1 );
			$email_type         = $options->get_option( 'mail-type', 'html' );
			$include_products   = $options->get_option( 'include-product' );
			$period_days        = (int) $options->get_option( 'period-days' );
			$offer_emails       = $options->get_option( 'offer_emails' );
			$current_time       = strtotime( current_time( 'mysql' ) );
			$last_time_added    = get_user_meta( $user_id, 'wlfmc_last_period_days', true );
			$exists             = true;
			$can_add_after_date = '' == $last_time_added ? $current_time : strtotime( '+' . $period_days . ' days', $last_time_added );
			$most_days          = 0;
			$need_coupon        = false;
			$coupon_amount      = $options->get_option( 'coupon-amount' );

			// check offer email exists and conditions is true or not
			if ( ! is_array( $offer_emails ) || empty( $offer_emails ) || $min_count > $wishlist->count_items() || $min_total > $wishlist->get_total() ) {
				return;
			}

			// Checked wishlist have one of the  product included or not
			if ( is_array( $include_products ) && ! empty( $include_products ) ) {
				$exists = false;
				foreach ( $include_products as $product_id ) {
					$product_id = wlfmc_object_id( $product_id, 'product', true, 'default' );

					/*if ( array_key_exists( $product_id, $wishlist->get_items() ) ) {
						$exists = true;
						break;
					}*/
					if ( $product_id === $prod_id ) {
						$exists = true;
						break;
					}

				}
			}

			if ( false === $exists || $can_add_after_date > $current_time ) {
				return;
			}


			foreach ( $offer_emails as $email_option ) {
				if ( isset( $email_option['enable_email'] ) && ( '1' == $email_option['enable_email'] ) &&
				     ( intval( $email_option['send_after_days'] ) > 0 ) &&
				     ( ( 'plain' === $email_type && wlfmc_str_contains( $email_option['text_content'], '{coupon_code}' ) ) || ( in_array( $email_type, array(
							     'html',
							     'mc-template'
						     ) ) && wlfmc_str_contains( $email_option['html_content'], '{coupon_code}' ) ) )
				) {
					$most_days = max( intval( $email_option['send_after_days'] ), $most_days );
				}
				if ( ( 'plain' === $email_type && wlfmc_str_contains( $email_option['text_content'], '{coupon_code}' ) ) || ( in_array( $email_type, array(
							'html',
							'mc-template'
						) ) && wlfmc_str_contains( $email_option['html_content'], '{coupon_code}' ) ) ) {
					$need_coupon = true;
				}
			}
			if ( ! $coupon_amount || ! floatval( $coupon_amount ) > 0 ) {
				$need_coupon = false;
			}

			$user               = get_userdata( $user_id );
			$current_user_email = $user->user_email;
			$expires_after_days = intval( $options->get_option( 'expiry-date' ) ) + $most_days;
			$date_expires       = strtotime( '+' . $expires_after_days . ' days', $current_time );
			$coupon_args        = array(
				'code'                 => $this->generate_coupon_code(),
				'discount_type'        => $options->get_option( 'discount-type', 'fixed_cart' ),
				'amount'               => $coupon_amount,
				'date_expires'         => $date_expires,
				'individual_use'       => '1' == $options->get_option( 'individual-use' , '0'),
				'exclude_sale_items'   => '1' == $options->get_option( 'exclude-sale-items' , '0'),
				'free_shipping'        => '1' == $options->get_option( 'free-shipping', '0' ),
				'email_restrictions'   => '1' == $options->get_option( 'user-restriction', '0' ) ? $current_user_email : '',
				'delete_after_expired' => '1' == $options->get_option( 'delete-after-expired', '0' ) ? 'yes' : 'no',
			);
			$coupon_id = $need_coupon ? $this->add_coupon( $coupon_args ) : null;

			foreach ( $offer_emails as $email_option ) {
				if ( isset( $email_option['enable_email'] ) && '1' == $email_option['enable_email'] ) {
					$days       = intval( $email_option['send_after_days'] );
					$datesend   = $days > 0 ? strtotime( '+' . $days . ' days', $current_time ) : $current_time;
					$has_coupon = ( ( 'plain' === $email_type && wlfmc_str_contains( $email_option['text_content'], '{coupon_code}' ) ) || ( in_array( $email_type, array(
								'html',
								'mc-template'
							) ) && wlfmc_str_contains( $email_option['html_content'], '{coupon_code}' ) ) ) ? 1 : 0;
					$this->insert_email( array(
						'user_id'           => $user_id,
						'wishlist_id'       => $wishlist_id,
						'has_coupon'        => $has_coupon,
						'coupon_id'         => $coupon_id,
						'product_id'        => $prod_id,
						'days'              => $days,
						'email_options'     => array(
							'mail_type'    => $email_type,
							'mail_heading' => $email_option['mail_heading'],
							'mail_subject' => $email_option['mail_subject'],
							'mail_content' => ( 'plain' == $email_type ) ? $email_option['text_content'] : $email_option['html_content'],
						),
						'condition_options' => array(
							'min_count'        => $min_count,
							'min_total'        => $min_total,
							'include_products' => $include_products,
						),
						'datesend'          => date( 'Y-m-d H:i:s', $datesend ),
					) );
				}

			}

			update_user_meta( $user_id, 'wlfmc_last_period_days', $current_time );


		}

		/**
		 * send offer email
		 *
		 * @param $email_row
		 *
		 * @throws Exception
		 * @version 1.3.0
		 */
		public function send_email( $email_row ) {

			$mailer             = WC()->mailer();
			$user               = get_userdata( $email_row->user_id );
			$to                 = $user->user_email;
			$email_options      = unserialize( $email_row->email_options );
			$email_content      = $email_options['mail_content'];
			$coupon_code        = '';
			$coupon_amount      = '';
			$coupon_expiry_date = '';
			$mc_options         = array();
			switch ( $email_options['mail_type'] ) {
				case 'mc-template':
					$content_type = 'text/html';
					$template     = 'mc-template.php';
					$options      = new MCT_Options( 'wlfmc_options' );
					$logo         = wp_get_attachment_image_src( $options->get_option( 'email-template-logo' ) );
					$avatar       = wp_get_attachment_image_src( $options->get_option( 'email-template-avatar' ) );
					$mc_options   = array(
						'logo'          => $logo ? $logo : '',
						'avatar'        => $avatar ? $avatar : '',
						'customer-name' => $options->get_option( 'email-template-customer-name' ),
						'customer-job'  => $options->get_option( 'email-template-customer-job' ),
						'facebook'      => $options->get_option( 'email-template-facebook' ),
						'linkedin'      => $options->get_option( 'email-template-linkedin' ),
						'instagram'     => $options->get_option( 'email-template-instagram' )
					);

					break;
				case 'html':
					$content_type = 'text/html';
					$template     = 'offer.php';

					break;
				case 'plain':
					$content_type = 'text/plain';
					$template     = 'plain/offer.php';

					break;
			}
			$headers         = "Content-Type: {$content_type}\r\n";
			$email_content   = $this->prepare_content( $email_content, $email_options['mail_type'] );
			$this->mail_type = $email_options['mail_type'];

			if ( 1 == $email_row->has_coupon ) {
				$coupon_object = new WC_Coupon( $email_row->coupon_id );
				$discounts     = new WC_Discounts();
				// check coupon valid
				if ( $discounts->is_coupon_valid( $coupon_object ) && wlfmc_str_contains( $email_content, '{coupon_code}' ) ) {
					$coupon_code        = $coupon_object->get_code();
					$coupon_amount      = $coupon_object->get_amount( 'view' );
					$coupon_expiry_date = $coupon_object->get_date_expires( 'view' );
				}
			}
			$wishlist     = WLFMC_Wishlist_Factory::get_wishlist( $email_row->wishlist_id );
			$wishlist_url = $wishlist->get_share_url();

			$shop_url     = get_permalink( wc_get_page_id( 'shop' ) );
			$checkout_url = add_query_arg( array(
				'add_all_to_cart' => 'true',
				'wishlist_id'     => $email_row->wishlist_id
			), $wishlist_url );

			$placeholders = array(
				'{user_name}'        => $user->user_login,
				'{user_email}'       => $user->user_email,
				'{user_first_name}'  => $user->first_name,
				'{user_last_name}'   => $user->last_name,
				'{coupon_code}'      => $coupon_code,
				'{coupon_amount}'    => $coupon_amount,
				'{expiry_date}'      => $coupon_expiry_date,
				'{shop_url}'         => esc_url( $shop_url ),
				'{checkout_url}'     => esc_url( $checkout_url ),
				'{wishlist_url}'     => esc_url( $wishlist_url ),
				'{site_name}'        => get_bloginfo( 'name' ),
				'{site_description}' => get_bloginfo( 'description' ),
				'{unsubscribe_url}'  => WLFMC()->get_unsubscribe_url( $user->ID ),
			);

			$email_content = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $email_content );

			unset( $placeholders['{shop_url}'] );
			unset( $placeholders['{checkout_url}'] );
			unset( $placeholders['{wishlist_url}'] );
			unset( $placeholders['{unsubscribe_url}'] );

			$email_heading = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $email_options['mail_heading'] );
			$email_subject = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $email_options['mail_subject'] );


			$message = wlfmc_get_template( 'emails/' . $template, array(
				'email'         => $mailer,
				'email_heading' => apply_filters( 'wlfmc_offer_email_heading', $email_heading ),
				'email_content' => apply_filters( 'wlfmc_offer_email_content', $email_content ),
				'mc_options'    => $mc_options,
				'wishlist_url'  => $wishlist_url,
			), true );


			add_filter( 'woocommerce_email_from_name', array( $this, 'get_from_name' ), 10 );
			add_filter( 'woocommerce_email_from_address', array( $this, 'get_from_address' ), 10 );
			add_filter( 'woocommerce_email_content_type', array( $this, 'get_content_type' ), 10 );


			$send_state = $mailer->send( $to, apply_filters( 'wlfmc_offer_email_subject', $email_subject ), $message, $headers, '' );

			remove_filter( 'woocommerce_email_from_name', array( $this, 'get_from_name' ), 10 );
			remove_filter( 'woocommerce_email_from_address', array( $this, 'get_from_address' ), 10 );
			remove_filter( 'woocommerce_email_content_type', array( $this, 'get_content_type' ), 10 );

			if ( $send_state ) {
				$this->set_sent( $email_row->ID );
			} else {
				$this->set_notsent( $email_row->ID );
			}

		}


		/**
		 * insert Email to DB
		 *
		 * @param $args
		 *
		 * @return int
		 * @version 1.0.1
		 */
		public function insert_email( $args ) {
			global $wpdb;

			$wpdb->insert(
				$wpdb->wlfmc_offers,
				array(
					'user_id'       => $args['user_id'],
					'wishlist_id'   => $args['wishlist_id'],
					'has_coupon'    => $args['has_coupon'],
					'coupon_id'     => $args['coupon_id'],
					'product_id'    => $args['product_id'],
					'email_options' => serialize( $args['email_options'] ),
					'datesend'      => $args['datesend'],
					'days'          => $args['days'],
				),
				array(
					'%d',
					'%d',
					'%d',
					'%d',
					'%d',
					'%s',
					'%s',
					'%d',
				)
			);

			return $wpdb->insert_id;

		}

		/**
		 * Generate Random coupon code
		 * @return string
		 */
		public function generate_coupon_code() {
			global $wpdb;

			$sql = "SELECT COUNT(*) FROM `{$wpdb->posts}` WHERE `post_title` = %s AND `post_status` = 'publish' AND  `post_type` = 'shop_coupon'";

			do {
				$dictionary = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
				$nchars     = 8;
				$code       = "";

				for ( $i = 0; $i <= $nchars - 1; $i ++ ) {
					$code .= $dictionary[ mt_rand( 0, strlen( $dictionary ) - 1 ) ];
				}

				$count = $wpdb->get_var( $wpdb->prepare( $sql, $code ) );
			} while ( $count != 0 );

			return $code;
		}

		/**
		 * add new coupon code
		 *
		 * @param $args
		 *
		 * @return int
		 */
		public function add_coupon( $args ) {

			$args = wp_parse_args(
				$args,
				array(
					'code'                        => '',
					'discount_type'               => 'fixed_cart',
					'amount'                      => '',
					'date_expires'                => null,
					'free_shipping'               => false,
					'email_restrictions'          => '',
					'usage_limit'                 => 1,
					'usage_limit_per_user'        => 1,
					'delete_after_expired'        => 'no',
					'individual_use'              => false,
					'product_ids'                 => array(),
					'excluded_product_ids'        => array(),
					'product_categories'          => array(),
					'excluded_product_categories' => array(),
					'exclude_sale_items'          => false,
					'minimum_amount'              => '',
					'maximum_amount'              => '',
				)
			);
			$args = apply_filters( 'wlfmc_add_coupon_offer_args', $args );

			$coupon = new WC_Coupon();

			$coupon->set_code( $args['code'] );

			//the coupon discount type can be 'fixed_cart', 'percent' or 'fixed_product', defaults to 'fixed_cart'
			$coupon->set_discount_type( $args['discount_type'] );

			//the discount amount, defaults to zero
			$coupon->set_amount( $args['amount'] );

			//the coupon's expiration date defaults to null
			$coupon->set_date_expires( $args['date_expires'] );

			//determines if the coupon can only be used by an individual, defaults to false
			$coupon->set_individual_use( $args['individual_use'] );

			//the individual prodcuts that the disciunt will apply to, default to an empty array
			$coupon->set_product_ids( $args['product_ids'] );

			//the individual products that are excluded from the discount, default to an empty array
			$coupon->set_excluded_product_ids( $args['excluded_product_ids'] );

			//the times the coupon can be used, defaults to zero
			$coupon->set_usage_limit( $args['usage_limit'] );

			//the times the coupon can be used per user, defaults to zero
			$coupon->set_usage_limit_per_user( $args['usage_limit_per_user'] );

			//whether the coupon awards free shipping, defaults to false
			$coupon->set_free_shipping( $args['free_shipping'] );

			//the product categories included in the promotion, defaults to an empty array
			$coupon->set_product_categories( $args['product_categories'] );

			//the product categories excluded from the promotion, defaults to an empty array
			$coupon->set_excluded_product_categories( $args['excluded_product_categories'] );

			//whether sale items are excluded from the coupon, defaults to false
			$coupon->set_exclude_sale_items( $args['exclude_sale_items'] );

			//the minimum amount of spend required to make the coupon active, defaults to an empty string
			$coupon->set_minimum_amount( $args['minimum_amount'] );

			//the maximum amount of spend required to make the coupon active, defaults to an empty string
			$coupon->set_maximum_amount( $args['maximum_amount'] );

			//a list of email addresses, the coupon will only be applied if the customer is linked to one of the listed emails, defaults to an empty array
			$coupon->set_email_restrictions( $args['email_restrictions'] );

			//save the coupon
			$coupon->save();

			if ( 'yes' == $args['delete_after_expired'] ) {
				update_post_meta( $coupon->get_id(), 'delete_after_expired', 'yes' );
			}

			return $coupon->get_id();


		}


		/**
		 * Set email offer to Sent
		 *
		 * @param $id
		 */
		public function set_sent( $id ) {
			global $wpdb;

			$wpdb->update(
				$wpdb->wlfmc_offers,
				array( 'is_sent' => 1 ),
				array( 'ID' => $id ),
				array( '%d' )
			);
		}

		/**
		 * Set email offer to NotSent
		 *
		 * @param $id
		 */
		public function set_notsent( $id ) {
			global $wpdb;

			$wpdb->update(
				$wpdb->wlfmc_offers,
				array( 'is_sent' => 2 ),
				array( 'ID' => $id ),
				array( '%d' )
			);
		}

		/**
		 * Delete email queue that not sent
		 */
		public function delete_email_queue() {
			global $wpdb;
			$wpdb->query( $wpdb->prepare( "DELETE FROM {$wpdb->wlfmc_offers} WHERE is_sent = 0 " ) );
		}


		/**
		 * Check admin option that user want to delete email queue or not
		 */
		public function check_for_delete_queue() {
			if ( isset( $_POST['delete-queue-emails'] ) && $_POST['delete-queue-emails'] == '1' ) {
				$this->delete_email_queue();
				$_POST['delete-queue-emails'] = '0';
			}
		}

		/**
		 * Check coupon used in orders and remove offers if coupon used.
		 *
		 * @param int $order_id Order ID.
		 */
		public function check_coupon_used( $order_id ) {

			global $wpdb;
			$order        = wc_get_order( $order_id );
			$coupon_codes = $order->get_coupon_codes();
			if ( is_array( $coupon_codes ) && ! empty( $coupon_codes ) ) {
				$wpdb->query( $wpdb->prepare( "DELETE FROM {$wpdb->wlfmc_offers} WHERE is_sent = 0 AND has_coupon = 1 AND coupon_id IN( " . implode( ', ', array_filter( $coupon_codes, 'esc_sql' ) ) . " )  " ) );
			}

		}

		/**
		 * Returns single instance of the class
		 *
		 * @return WLFMC_Offer_Emails
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

	}
}
/**
 * Unique access to instance of WLFMC_Offer_Emails class
 *
 * @return WLFMC_Offer_Emails
 */
function WLFMC_Offer_Emails() {
	return WLFMC_Offer_Emails::get_instance();
}

