<?php
/**
 * Smart Wishlist Email Automation
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 *
 * @since 1.2.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
if ( ! class_exists( 'WLFMC_Email_Automation' ) ) {
	/**
	 * This class handles Email automation for wishlist
	 */
	class WLFMC_Email_Automation {

		/**
		 * Single instance of the class
		 *
		 * @var WLFMC_Email_Automation
		 */
		protected static $instance;

		/**
		 * Constructor
		 *
		 * @return void
		 *
		 */
		public function __construct() {
			add_action( 'wlfmc_email-automation_admin_settings', array(
				$this,
				'show_email_automation_settings'
			), 10 );
			add_action( 'wp_ajax_wlfmc_send_offer_email_test', array( $this, 'ajax_send_offer_email_test_callback' ) );

		}


		/**
		 * Returns single instance of the class
		 *
		 * @return WLFMC_Email_Automation
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * Show email automation settings
		 *
		 * @param $main_options
		 */
		public function show_email_automation_settings( $main_options ) {

			unset( $main_options['options']['button-display'] );
			$fields = new MCT_Fields( $main_options );
			$fields->output();
		}

		/**
		 * Send offer email for testing
		 *
		 */
		public function ajax_send_offer_email_test_callback() {
			check_ajax_referer( 'ajax-nonce', 'key' );

			$id    = isset( $_POST['id'] ) ? sanitize_text_field( $_POST['id'] ) : '';
			$field = isset( $_POST['field'] ) ? sanitize_text_field( $_POST['field'] ) : '';

			if ( '' === $field || '' === $id ) {

				exit;
			}

			$options = new MCT_Options( 'wlfmc_options' );

			$email_type = $options->get_option( 'mail-type', 'html' );
			$offers     = $options->get_option( $field );

			if ( ! $offers || ! isset( $offers[ $id ] ) ) {

				echo wp_json_encode( array(
					'message' => __( 'Save the email settings first, then try again', 'wc-wlfmc-wishlist' ),
					'success' => false
				) );
				exit;
			}


			$mailer            = WC()->mailer();
			$WLFMC_Offer_Email = new WLFMC_Offer_Email( $email_type );
			$user              = get_userdata( get_current_user_id() );
			$to                = $user->user_email;
			$email_options     = $offers[ $id ];
			$email_content     = $content_type = '';
			$mc_options        = array();

			switch ( $email_type ) {
				case 'mc-template':
					$content_type = 'text/html';
					$template     = 'mc-template.php';

					$email_content = ( '' === $email_options['html_content'] ) ? $WLFMC_Offer_Email::get_default_content( 'html', $id ) : $email_options['html_content'];
					$logo          = wp_get_attachment_image_src( $options->get_option( 'email-template-logo' ) );
					$avatar        = wp_get_attachment_image_src( $options->get_option( 'email-template-avatar' ) );

					$mc_options = array(
						'logo'          => $logo ? $logo : '',
						'avatar'        => $avatar ? $avatar : '',
						'customer-name' => $options->get_option( 'email-template-customer-name' ),
						'customer-job'  => $options->get_option( 'email-template-customer-job' ),
						'facebook'      => $options->get_option( 'email-template-facebook' ),
						'linkedin'      => $options->get_option( 'email-template-linkedin' ),
						'instagram'     => $options->get_option( 'email-template-instagram' )
					);
					break;
				case 'html':
					$content_type  = 'text/html';
					$template      = 'offer.php';
					$email_content = ( '' === $email_options['text_content'] ) ? $WLFMC_Offer_Email::get_default_content( 'html', $id ) : $email_options['html_content'];
					break;
				case 'plain':
					$content_type  = 'text/plain';
					$template      = 'plain/offer.php';
					$email_content = ( '' === $email_options['text_content'] ) ? $WLFMC_Offer_Email::get_default_content( 'plain', $id ) : $email_options['text_content'];

					break;
			}

			$email_content = $WLFMC_Offer_Email->prepare_content( $email_content, $email_type );

			$headers = "Content-Type: {$content_type}\r\n";


			$placeholders  = array(
				'{user_name}'        => $user->user_login,
				'{user_email}'       => $user->user_email,
				'{user_first_name}'  => $user->first_name,
				'{user_last_name}'   => $user->last_name,
				'{site_name}'        => get_bloginfo( 'name' ),
				'{site_description}' => get_bloginfo( 'description' ),

			);
			$email_content = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $email_content );

			$email_heading = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $email_options['mail_heading'] );
			$email_subject = str_replace( array_keys( $placeholders ), array_values( $placeholders ), $email_options['mail_subject'] );

			$message = wlfmc_get_template( 'emails/' . $template, array(
				'email'         => $mailer,
				'email_heading' => apply_filters( 'wlfmc_offer_email_heading', $email_heading ),
				'email_content' => apply_filters( 'wlfmc_offer_email_content', $email_content ),
				'mc_options'    => $mc_options,
				'wishlist_url'  => '#!',
			), true );


			add_filter( 'woocommerce_email_from_name', array( $WLFMC_Offer_Email, 'get_from_name' ), 10 );
			add_filter( 'woocommerce_email_from_address', array( $WLFMC_Offer_Email, 'get_from_address' ), 10 );
			add_filter( 'woocommerce_email_content_type', array( $WLFMC_Offer_Email, 'get_content_type' ), 10 );

			$send_state = $mailer->send( $to, apply_filters( 'wlfmc_offer_email_subject_test', $email_subject ), $message, $headers, '' );

			remove_filter( 'woocommerce_email_from_name', array( $WLFMC_Offer_Email, 'get_from_name' ), 10 );
			remove_filter( 'woocommerce_email_from_address', array( $WLFMC_Offer_Email, 'get_from_address' ), 10 );
			remove_filter( 'woocommerce_email_content_type', array( $WLFMC_Offer_Email, 'get_content_type' ), 10 );


			if ( $send_state ) {
				echo wp_json_encode( array(
					/* translators: %s: email address */
					'message' => sprintf( __( 'Email sent to %s.', 'wc-wlfmc-wishlist' ), $to ),
					'success' => true
				) );
			} else {
				echo wp_json_encode( array(
					'message' => __( 'There was a problem sending the email.', 'wc-wlfmc-wishlist' ),
					'success' => false
				) );
			}

			exit;
		}

	}
}


/**
 * Unique access to instance of WLFMC_Email_Automation class
 *
 * @return WLFMC_Email_Automation
 */
function WLFMC_Email_Automation() {
	return WLFMC_Email_Automation::get_instance();
}
