(function ($) {
	var mc_validate_field = function (object) {
		if (
			object[0].validity.badInput === false &&
			!object.is(":required") || !object.is(':visible')
		) {
			if (object.hasClass("validate")) {
				object.removeClass("valid");
				object.removeClass("invalid");
			}
		} else {
			if (object.hasClass("validate")) {
				// Check for character counter attributes
				if (object.is(":valid")) {
					object.removeClass("invalid");
					object.addClass("valid");
				} else {
					object.removeClass("valid");
					object.addClass("invalid");
					if (!object.siblings('.error').length)
						$('<label class="error">' + object.data('error') + '</label>').insertAfter(object);
				}
			}
		}
	};

	$(function () {
		'use strict';

		function initValidate() {
			/**
			 * Validate input and textarea
			 *
			 * @type {string}
			 */
				// Text based inputs
			var input_selector =
					"input[type=text], input[type=password], input[type=email], input[type=url], input[type=tel], input[type=number], input[type=search], input[type=date], input[type=time], textarea";


			$(document).on("change input cut copy paste", input_selector, function () {
				mc_validate_field($(this));
			});
			// HTML DOM FORM RESET handling
			$(document).on("reset", function (e) {
				var formReset = $(e.target);
				if (formReset.is("form")) {
					formReset
						.find(input_selector)
						.removeClass("valid")
						.removeClass("invalid");
				}
			});

			document.addEventListener(
				"blur",
				function (e) {
					var $inputElement = $(e.target);
					if ($inputElement.is(input_selector)) {
						mc_validate_field($inputElement);
					}
				},
				true
			);

		}

		$(document.body).on('mc-sidebar-init', function () {
			if ($('.mct-sidebar').length > 0) {
				var msie6 = $.browser === 'msie' && $.browser.version < 7;

				if (!msie6 && $('.mct-sidebar').offset() != null) {
					if ($(window).width() > 992) {
						var section_height = $('.mct-section-wrapper').offset() != null && !$('.mct-section-wrapper').is(":hidden") ? $('.mct-section-wrapper').height() : 0;

						$('.mct-options').each(function (index, elem) {
							var sidebar = $(elem).find('.mct-sidebar');
							if (sidebar.offset() != null) {
								var top_sidebar = sidebar.offset().top - parseFloat($(elem).css('margin-top').replace(/auto/, 0)),
									height = $(elem).find('.mct-sidebar-inner').height(),
									winHeight = $(window).height(),
									gap = 30,
									offsetbottom = 100,
									top = top_sidebar - section_height;
								$(window).scroll(function (event) {
									var y = $(this).scrollTop();
									var footerTop = $('.mct-footer').offset().top - parseFloat($('.mct-footer').css('margin-top').replace(/auto/, 0));

									if ($(window).width() > 992 && y > top) {

										var p = (y + height + offsetbottom) > footerTop ? -1 * (height + offsetbottom - (footerTop - (y + winHeight)) - winHeight) : 0;
										sidebar.addClass('sidebarfixed').css({'top': p, 'width': '300px'});

									} else {
										sidebar.removeClass('sidebarfixed').removeAttr('style');
									}

								});
							}

						});

					} else {
						$('.mct-sidebar').removeClass('sidebarfixed').removeAttr('style');
					}

				}
			}
		}).trigger('mc-sidebar-init');


		$(document.body).on('mc-wizard-next-step', function () {


			var elem = $('.next-step:visible');
			var input_selector =
				"input[type=text], input[type=password], input[type=email], input[type=url], input[type=tel], input[type=number], input[type=search], input[type=date], input[type=time], textarea";

			var input_fields = elem.closest('.wizard-content').find(input_selector);
			$(input_fields).each(function (index, item) {
				mc_validate_field($(item));
			}).promise().done(function () {

				var invalid_fields = elem.closest('.wizard-content').find('.invalid');
				if (!invalid_fields.length) {
					var step = $('.step-success'),
						current_step = step.data('step'),
						next_step = step.next().attr('data-step');
					$('.step-' + current_step).removeClass('step-success');
					$('.step-' + next_step).addClass('step-success');
					$('.wizard-content').hide();
					$('.wizard-content.' + next_step).show();
					window.history.replaceState('', '', updateURLParameter(window.location.href, "step", next_step));
				}

			});


		});
		$(document.body).on('mc-wizard-back-step', function () {
			var step = $('.step-success'),
				current_step = step.data('step'),
				prev_step = step.prev().attr('data-step');
			$('.step-' + current_step).removeClass('step-success');
			$('.step-' + prev_step).addClass('step-success');
			$('.wizard-content').hide();
			$('.wizard-content.' + prev_step).show();
			window.history.replaceState('', '', updateURLParameter(window.location.href, "step", prev_step));
		});

		function initWizard() {

			$('body').on('click', '.mct-wizard .last.next-step', function (event) {
				event.stopPropagation();
				event.preventDefault();
				$('.wizard-form').submit();
				return false;
			});
			$('body').on('click', '.mct-wizard .back-step', function (event) {
				event.preventDefault();
				$(document.body).trigger('mc-wizard-back-step');
				return false;
			});
			$('body').on('click', '.mct-wizard .next-step:not(.last)', function (event) {
				event.preventDefault();
				$(document.body).trigger('mc-wizard-next-step');
				return false;
			});

		}

		function initColorpicker() {

			var setColorOpacity = function (colorStr, opacity) {
				var rgbaCol;
				if (colorStr.indexOf("rgb(") == 0) {
					rgbaCol = colorStr.replace("rgb(", "rgba(");
					rgbaCol = rgbaCol.replace(")", ", " + opacity + ")");
					return rgbaCol;
				}

				if (colorStr.indexOf("rgba(") == 0) {
					rgbaCol = colorStr.substr(0, colorStr.lastIndexOf(",") + 1) + opacity + ")";
					return rgbaCol;
				}

				if (colorStr.length == 6)
					colorStr = "#" + colorStr;

				if (colorStr.indexOf("#") == 0) {
					rgbaCol = 'rgba(' + parseInt(colorStr.slice(-6, -4), 16) + ',' + parseInt(colorStr.slice(-4, -2), 16) + ',' + parseInt(colorStr.slice(-2), 16) + ',' + opacity + ')';
					return rgbaCol;
				}
				return colorStr;
			};

			// Add Color Picker to all inputs that have 'mct-color-picker' class
			$('.mct-color-picker').wpColorPicker({
				change: function (event, ui) {

					var color = setColorOpacity(ui.color.toString(), ui.color._alpha);
					var background = 'linear-gradient(' + color + ' 0%, ' + color + ' 100%) repeat scroll 0% 0% ,url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAAHnlligAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAHJJREFUeNpi+P///4EDBxiAGMgCCCAGFB5AADGCRBgYDh48CCRZIJS9vT2QBAggFBkmBiSAogxFBiCAoHogAKIKAlBUYTELAiAmEtABEECk20G6BOmuIl0CIMBQ/IEMkO0myiSSraaaBhZcbkUOs0HuBwDplz5uFJ3Z4gAAAABJRU5ErkJggg==") repeat scroll 0% 0%';
					$(this).closest('.wp-picker-container').find('.wp-color-result').css('background-color', '#fff');
					$(this).closest('.wp-picker-container').find('.color-alpha').css('background', background);
					$(this).closest('.wp-picker-container').find('.color-alpha').css('border-color', color);
				},
				clear: function (event, ui) {
					$(this).closest('.wp-picker-container').find('.wp-color-result').css('background-color', '#fff');
					$(this).closest('.wp-picker-container').find('.color-alpha').css('border-color', '#e4dbd0');
					$(this).closest('.wp-picker-container').find('.color-alpha').css('background', 'none');
				}
			});
			$('.mct-wrapper .wp-picker-container').each(function (index, elem) {
				//var border = $(elem).find('.wp-color-result').css('background-color');
				var border = $(elem).find('.wp-color-picker').val();


				if ('rgb(255, 255, 255)' !== border) {
					var background = 'linear-gradient(' + border + ' 0%, ' + border + ' 100%) repeat scroll 0% 0% ,url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAAHnlligAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAHJJREFUeNpi+P///4EDBxiAGMgCCCAGFB5AADGCRBgYDh48CCRZIJS9vT2QBAggFBkmBiSAogxFBiCAoHogAKIKAlBUYTELAiAmEtABEECk20G6BOmuIl0CIMBQ/IEMkO0myiSSraaaBhZcbkUOs0HuBwDplz5uFJ3Z4gAAAABJRU5ErkJggg==") repeat scroll 0% 0%';
					$(elem).closest('.wp-picker-container').find('.color-alpha').css('border-color', border);
					$(elem).closest('.wp-picker-container').find('.color-alpha').css('background', background);
					$(elem).find('.wp-color-result').css('background-color', '#fff');
				}


			});
			$('.mct-wrapper .wp-picker-container').on('click.wpcolorpicker', function (event) {
				var elem = $(event.currentTarget),
					offset = elem.offset(),
					pagewidth = $(document).width(),
					position = 0,
					pickerwidth = 260,
					adminmenu = $('#adminmenu').is(":visible") ? $('#adminmenu').width() : 0;

				position = offset.left - adminmenu - 50;

				if ((position + pickerwidth + adminmenu + 50) > pagewidth) {
					position = offset.left - pickerwidth - adminmenu;
				}
				if (position < 5) {
					position = 5;
				}

				elem.find('.wp-picker-holder').css('left', position + 'px');
				elem.find('.wp-picker-input-wrap').css('left', position + 'px');

			});
		}

		function initSelect2() {
			$('.select2-trigger').select2({
				'width': '100%',
				minimumResultsForSearch: 8
			});
			$(document.body).trigger('wc-enhanced-select-init');

		}

		$('.mct-repeater.simple-repeater').repeater(
			{
				limitMessage: mct_admin_params.i18n_limit_repeater_alert,
				show: function () {
					$(this).slideDown();

					$.each($(this).find('.wp-picker-container'), function (index, elem) {
						var field = $(elem).find('.mct-color-picker').clone();
						$(elem).before(field);
					});
					$(this).find('.wp-picker-container').remove();

					$(this).find('.select2-hidden-accessible').removeClass('enhanced').removeClass('select2-hidden-accessible');
					$(this).find('.select2-container').remove();

					initColorpicker();
					init_repeater_dependencies();
					initSelect2();
				},
				hide: function (deleteElement) {
					if (confirm(mct_admin_params.i18n_delete_repeater_confirm)) {

						$(this).slideUp(deleteElement);

					}
				},
				ready: function (setIndexes) {

				}
			}
		);

		$('.mct-repeater.nested-repeater').repeater(
			{
				limitMessage: mct_admin_params.i18n_limit_repeater_alert,
				repeaters: [{
					// (Required)
					// Specify the jQuery selector for this nested repeater
					selector: '.inner-repeater',
					show: function () {
						$(this).slideDown();

						$.each($(this).find('.wp-picker-container'), function (index, elem) {
							var field = $(elem).find('.mct-color-picker').clone();
							$(elem).before(field);
						});
						$(this).find('.wp-picker-container').remove();

						$(this).find('.select2-hidden-accessible').removeClass('enhanced').removeClass('select2-hidden-accessible');
						$(this).find('.select2-container').remove();

						initColorpicker();
						init_repeater_dependencies();
						initSelect2();

					},
				}],
				show: function () {
					$(this).slideDown();

					/**
					 * Remove extra rows after add new repeater Group
					 */
					if ($(this).find('tr').length > 1) {

						$.each($(this).find('tr'), function (index, elem) {

							if (index > 0) {
								elem.remove();
							}
						});
					}


					$.each($(this).find('.wp-picker-container'), function (index, elem) {
						var field = $(elem).find('.mct-color-picker').clone();
						$(elem).before(field);
					});
					$(this).find('.wp-picker-container').remove();

					$(this).find('.select2-hidden-accessible').removeClass('enhanced').removeClass('select2-hidden-accessible');
					$(this).find('.select2-container').remove();

					initColorpicker();
					init_repeater_dependencies();
					initSelect2();

				},
			}
		);

		/**
		 * Add a click event to the "+" button in the inner-repeater  row
		 */
		$('body').on('click', '.inner-repeater .add-new-row', function (e) {
			e.preventDefault();
			$(this).closest('.inner-repeater').find('[data-repeater-create]').trigger('click');
			return false;
		});
		// The "Upload" button
		$('.mct_upload_image_button').click(function () {

			var send_attachment_bkp = wp.media.editor.send.attachment;
			var button = $(this);

			wp.media.editor.send.attachment = function (props, attachment) {
				$(button).parent().prev().attr('src', attachment.url);
				$(button).prev().val(attachment.id);
				wp.media.editor.send.attachment = send_attachment_bkp;
			};
			wp.media.editor.open(button);
			return false;
		});

		// The "Remove" button (remove the value from input type='hidden')
		$('.mct_remove_image_button').click(function () {
			var answer = confirm('Are you sure?');
			if (answer === true) {
				var src = $(this).parent().prev().attr('data-src');
				$(this).parent().prev().attr('src', src);
				$(this).prev().prev().val('');
			}
			return false;
		});

		$('body').on('click', '.mct-sections a', function (event) {
			event.preventDefault();
			$('.mct-section-wrapper').hide();
			$('.mct-section-content').hide();
			$($(this).attr('href')).show();
			var new_url = removeURLParams('tab');
			window.history.replaceState('', '', new_url);
			window.history.replaceState('', '', updateURLParameter(window.location.href, "section", $(this).attr('href')));
			$('.mct-sidebar').removeClass('sidebarfixed').removeAttr('style');
			$(document.body).trigger('mc-sidebar-init');
		});

		$('body').on('click', '.mct-back-btn', function (event) {
			event.preventDefault();
			$('.mct-section-content').hide();
			$('.mct-section-wrapper').show();
		});

		$('body').on('click', '.mct-tabs a:not(.external-link)', function (event) {
			event.preventDefault();
			$(this).closest('.mct-section-content').find('.mct-tab-content').hide();
			$(this).closest('.mct-section-content').find('.mct-tabs a').removeClass('nav-tab-active');
			$(this).addClass('nav-tab-active');
			$($(this).attr('href')).show();
			window.history.replaceState('', '', updateURLParameter(window.location.href, "tab", $(this).attr('href')));
			return false;
		});

		$('body').on('click', '.mct-copy-btn', function (event) {
			event.preventDefault();
			var textBox = $(this).parent().find('.mct-copy-text');
			textBox.select();
			document.execCommand("copy");
		});

		$('body').on('click', '.show-manage-item', function (event) {
			event.preventDefault();
			$('.mct-manage-item').hide();
			$($(this).attr('href')).closest('.mct-tab-content').find('> .form-table').hide();
			$($(this).attr('href')).closest('.mct-tab-content').find('> .mct-article').hide();
			$($(this).attr('href')).show();
			$("html, body").animate({scrollTop: 0}, "slow");
			return false;

		});

		$('body').on('click', '.back-manage-item', function (event) {
			event.preventDefault();
			$(this).closest('.mct-tab-content').find('> .form-table').show();
			$(this).closest('.mct-tab-content').find('> .mct-article').show();
			$('.mct-manage-item').hide();
			init_dependencies();
			init_section_dependencies();
			init_repeater_dependencies();
			init_manage_dependencies();
			return false;
		});

		// collapsible article
		$('body').on('click', '.article-title h2', function (event) {
			event.preventDefault();
			$(this).closest('.mct-article').toggleClass('collapsed');
			return false;
		});
		// Reset form
		$('body').on('click', '.mct-reset-btn', function (event) {
			//event.preventDefault();
			if (!confirm(mct_admin_params.i18n_reset_confirm)) {
				return false;
			}

		});

		//modal
		// Quick & dirty toggle to demonstrate modal toggle behavior
		$('body').on('click', '.modal-toggle', function (e) {
			e.preventDefault();
			var modal = $(this).data('modal');
			console.log(modal);
			$('#' + modal).removeAttr('style').toggleClass('is-visible');
		});

		function updateURLParameter(url, param, paramVal) {
			var newAdditionalURL = "";
			var tempArray = url.split("?");
			var baseURL = tempArray[0];
			var additionalURL = tempArray[1];
			var temp = "";
			if (additionalURL) {
				tempArray = additionalURL.split("&");
				for (var i = 0; i < tempArray.length; i++) {
					if (tempArray[i].split('=')[0] !== param) {
						newAdditionalURL += temp + tempArray[i];
						temp = "&";
					}
				}
			}

			var rows_txt = temp + "" + param + "=" + paramVal.replace('#', '');
			return baseURL + "?" + newAdditionalURL + rows_txt;
		}

		function removeURLParams(sParam) {
			var url = window.location.href.split('?')[0] + '?';
			var sPageURL = decodeURIComponent(window.location.search.substring(1)),
				sURLVariables = sPageURL.split('&'),
				sParameterName,
				i;

			for (i = 0; i < sURLVariables.length; i++) {
				sParameterName = sURLVariables[i].split('=');
				if (sParameterName[0] !== sParam) {
					url = url + sParameterName[0] + '=' + sParameterName[1] + '&';
				}
			}
			return url.substring(0, url.length - 1);
		}

		// Handle dependencies.
		function dependencies_handler(deps, values) {
			var result = true;
			//Single dependency
			if (typeof (deps) == 'string') {
				deps = $(deps);
			}


			var input_type = deps.data('type'),
				val = deps.val();

			if ('checkbox' === input_type) {
				val = deps.is(':checked') ? '1' : '0';
			} else if ('radio' === input_type) {
				val = deps.find('input[type="radio"]').filter(':checked').val();
			} else if ('checkbox-group' === input_type) {
				val = [];
				deps.find('input[type="checkbox"]:checked').each(function () {
					val.push($(this).val());
				});

			}

			values = values.split(',');

			for (var i = 0; i < values.length; i++) {
				if ($.isArray(val)) {
					if (val.includes(values[i])) {
						result = true;
						break;
					} else {
						result = false;
					}
				} else {

					if (val !== values[i]) {
						result = false;
					} else {
						result = true;
						break;
					}
				}

			}


			return result;

		}

		function init_repeater_dependencies() {
			$('[data-repdeps]:not( .deps-initialized )').each(function () {

				var t = $(this),
					field = t.closest('.row-options'),
					items = $.isArray(t.data('repdeps')) ? t.data('repdeps') : [t.data('repdeps')];

				// init field deps
				t.addClass('deps-initialized');
				$.each(items, function (index, data) {

					var className = data.id,
						wrapper = t.closest('tr'),
						elem = wrapper.find('.' + className);

					$(elem).on('change', function () {
						var showing = true;
						$.each(items, function (i, d) {
							var el = wrapper.find('.' + d.id);
							showing = (true === dependencies_handler(el, d.value) && showing);
						});
						if (showing) {
							field.show();
						} else {
							field.hide();
						}

					}).trigger('change');

				});

			});
		}

		function init_manage_dependencies() {
			$('[data-mngdeps]:not( .deps-initialized )').each(function () {
				var t = $(this);
				var field = t.closest('.row-options');
				// init field deps
				t.addClass('deps-initialized');

				var deps = '#' + t.data('mngdeps'),
					value = t.data('deps-value'),
					wrapper = t.closest('.row-options');

				$(deps).on('change', function () {
					var showing = dependencies_handler(deps, value.toString());
					if (showing) {
						field.show(300);
					} else {
						field.hide(300);
					}
				}).trigger('change');
			});
		}

		function init_dependencies() {
			$('[data-deps]:not( .deps-initialized, .mct-article )').each(function () {
				var t = $(this),
					field = t.closest('.row-options'),
					items = $.isArray(t.data('deps')) ? t.data('deps') : [t.data('deps')];

				// init field deps
				t.addClass('deps-initialized');
				$.each(items, function (index, data) {

					$('#' + data.id).on('change', function () {
						var showing = true;
						$.each(items, function (i, d) {
							showing = (true === dependencies_handler('#' + d.id, d.value) && showing);
						});
						if (showing) {
							field.show();
						} else {
							field.hide();
						}

					}).trigger('change');


				});
			});
		}

		function init_section_dependencies() {
			$('.mct-article[data-deps]:not( .deps-initialized )').each(function () {
				var t = $(this),
					items = $.isArray(t.data('deps')) ? t.data('deps') : [t.data('deps')];

				// init field deps
				t.addClass('deps-initialized');
				$.each(items, function (index, data) {

					$('#' + data.id).on('change', function () {
						var showing = true;
						$.each(items, function (i, d) {
							showing = (true === dependencies_handler('#' + d.id, d.value) && showing);
						});
						if (showing) {
							t.fadeIn(300);
						} else {
							t.fadeOut(300);
						}

					}).trigger('change');

				});
			});
		}

		init_dependencies();
		init_section_dependencies();
		init_repeater_dependencies();
		init_manage_dependencies();
		initColorpicker();
		initSelect2();
		initWizard();
		initValidate();
		$(window).on('resize', function () {
			if ($('.mct-sidebar').length > 0)
				$(document.body).trigger('mc-sidebar-init');
		});

	});
})(jQuery);
