<?php
/**
 * Plugin Name: MC Woocommerce Wishlist
 * Plugin URI: http://moreconvert.com/smart-wishlist-for-more-convert
 * Description: With the MC Wishlist plugin, your website users can add their favorite products to the wishlist. Then you can persuade them to buy products on their wishlist through the magic of our Marketing Toolkits.
 * Version: 1.3.1
 * Author: MoreConvert
 * Author URI: https://moreconvert.com
 * Text Domain: wc-wlfmc-wishlist
 * Domain Path: /languages/
 * WC requires at least: 5.3
 * WC tested up to: 6.5.1
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.3.1
 */

/**
 * Copyright 2020  Your Inspiration Solutions (email : info@moreconvert.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 3, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( ! defined( 'MC_WLFMC_URL' ) ) {
	define( 'MC_WLFMC_URL', plugin_dir_url( __FILE__ ) );
}

if ( ! defined( 'MC_WLFMC_MAIN_FILE' ) ) {
	define( 'MC_WLFMC_MAIN_FILE', __FILE__ );
}

if ( ! defined( 'MC_WLFMC_DIR' ) ) {
	define( 'MC_WLFMC_DIR', plugin_dir_path( __FILE__ ) );
}

if ( ! defined( 'MC_WLFMC_INC' ) ) {
	define( 'MC_WLFMC_INC', MC_WLFMC_DIR . 'includes/' );
}


add_action( 'plugins_loaded', 'wlfmc_wishlist_install', 20 );
register_activation_hook( __FILE__, 'wlfmc_activation_function' );

/***
 * Plugin install
 *
 * @return void
 * @version 1.3.1
 */
function wlfmc_wishlist_install() {

	if ( ! function_exists( 'is_plugin_active' ) ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}

	if ( ! function_exists( 'WC' ) ) {
		add_action( 'admin_notices', 'wlfmc_install_woocommerce_admin_notice' );
	} else {
		load_plugin_textdomain( 'wc-wlfmc-wishlist', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

		// Load required classes and functions.
		require_once MC_WLFMC_INC . 'data-stores/class-wlfmc-wishlist-data-store.php';
		require_once MC_WLFMC_INC . 'data-stores/class-wlfmc-wishlist-item-data-store.php';
		require_once MC_WLFMC_INC . 'emails/class-wlfmc-offer-email.php';
		require_once MC_WLFMC_INC . 'emails/class-wlfmc-offer-emails.php';
		require_once MC_WLFMC_INC . 'functions.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-exception.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-form-handler.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-ajax-handler.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-session.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-cron.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-wishlist.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-wishlist-item.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-wishlist-factory.php';
		require_once MC_WLFMC_INC . 'class-wlfmc.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-frontend.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-install.php';
		require_once MC_WLFMC_INC . 'class-wlfmc-shortcode.php';
		require_once MC_WLFMC_DIR . 'options/init.php';
		require_once MC_WLFMC_INC . 'elementor/class-wlfmc-elementor.php';
		require_once MC_WLFMC_INC . 'gutenberg/class-wlfmc-gutenberg.php';
		require_once MC_WLFMC_INC . 'widgets/class-wlfmc-counter-widget.php';

		mct_option_plugin_loader( MC_WLFMC_DIR );

		if ( is_admin() ) {
			require_once MC_WLFMC_INC . 'class-wlfmc-admin.php';
			require_once MC_WLFMC_INC . 'class-wlfmc-admin-notice.php';
			require_once MC_WLFMC_INC . 'marketing-toolkits/class-wlfmc-email-automation.php';

		}

		// Integration
		require_once MC_WLFMC_INC . 'integrations/astra.php';
		require_once MC_WLFMC_INC . 'integrations/flatsome.php';
		require_once MC_WLFMC_INC . 'integrations/rehub.php';
		require_once MC_WLFMC_INC . 'integrations/kallyas.php';
		require_once MC_WLFMC_INC . 'integrations/oceanwp.php';
		require_once MC_WLFMC_INC . 'integrations/botiga.php';
		require_once MC_WLFMC_INC . 'integrations/metro.php';
		require_once MC_WLFMC_INC . 'integrations/divi.php';
		require_once MC_WLFMC_INC . 'integrations/storefront.php';
		// Let's start!

		WLFMC();

	}
}

/**
 * Shows admin notice when plugin is activated without WooCommerce
 *
 * @return void
 */
function wlfmc_install_woocommerce_admin_notice() {
	?>
	<div class="error">
		<p><?php echo esc_html( 'Smart WooCommerce Wishlist For More Convert ' . __( 'is enabled but not effective. It requires WooCommerce to work.', 'wc-wlfmc-wishlist' ) ); ?></p>
	</div>
	<?php
}

/**
 * Operation after activating the plugin.
 *
 * @return void
 * @version 1.2.0
 */
function wlfmc_activation_function() {
	flush_rewrite_rules();

	set_transient( '_wlfmc_wishlist_activation_redirect', true, 30 );

	update_option( 'smart-wishlist-for-more-convert_tracking_notice', 'hide' );

	update_option( 'wlfmc-skip-wizard-notice', true );

	update_option( 'wlfmc-finish-wizard-notice', true );

	// If our option doesn't exist already, we'll create it with today's timestamp.
	if ( ! get_option( 'wlfmc_wishlist_activation_date' ) ) {
		update_option( 'wlfmc_wishlist_activation_date', date( 'Y-m-d' ) );
	}
}

if ( ! function_exists( 'log_me' ) ) {
	/**
	 * Manual Log
	 *
	 * @param Array|String|Object $message A message for log.
	 */
	function log_me( $message ) {

		if ( is_array( $message ) || is_object( $message ) ) {
			error_log( print_r( $message, true ) ); // @codingStandardsIgnoreLine.
		} else {
			error_log( $message ); // @codingStandardsIgnoreLine.
		}

	}
}


require __DIR__ . '/vendor/autoload.php';


/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_smart_wishlist_for_more_convert() {

	if ( ! class_exists( 'Appsero\Client' ) ) {
		require_once __DIR__ . '/appsero/src/Client.php';
	}

	$client = new Appsero\Client( '4fd3ce9d-2f72-4d4d-9344-ac3b11fb6a9c', 'MC Woocommerce Wishlist Plugin', __FILE__ );

	// Active insights
	$client->insights()->init();

}

appsero_init_tracker_smart_wishlist_for_more_convert();



