<?php
/**
 * Wishlist Counter template;
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.3
 */

/**
 * Template Variables:
 *
 * @var $show_icon                  string yes/no
 * @var $show_text                  string yes/no
 * @var $show_counter               string yes/no
 * @var $fragment_options           array Array of items to use for fragment generation
 * @var $wishlist                   WLFMC_WCWL_Wishlist Current wishlist
 * @var $wishlist_items             array Array of items to show for current page
 * @var $per_page                   int Items per page
 * @var $show_products              string yes/no
 * @var $dropdown_products          string yes/no
 * @var $counter_text               string Current page
 * @var $icon                       html
 * @var $hide_zero_products_number  bool
 * @var $products_number_position   string
 * @var $add_link_title             bool
 * @var $wishlist_link_position     string
 * @var $wishlist_link_title        string
 * @var $wishlist_url               url
 * @var $empty_wishlist_content     string string of no product in wishlist
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

?>

<div
	class="wlfmc_products_counter_wrapper  woocommerce wlfmc-wishlist-fragment on-first-load"
	data-fragment-options="<?php echo esc_attr( json_encode( $fragment_options ) ); ?>">
	<?php if ( 'yes' === $show_icon || 'yes' === $show_text ): ?>
		<a href="<?php echo $add_link_title &&  'no' === $show_products ? esc_url( $wishlist_url ) : '#!'; ?>"
		   class="wlfmc_products_counter  <?php echo 'yes' === $dropdown_products ? 'has-dropdown' : ''; ?> products-number-position-<?php echo $products_number_position; ?>">
			<?php if ( 'yes' === $show_icon ): ?>
				<span class="wlfmc_counter_icon">
				<?php echo wp_kses( $icon, wlfmc_get_kses_svg() ); ?>
			</span>
			<?php endif; ?>
			<?php if ( 'left' === $products_number_position && 'yes' === $show_counter && ( ( $wishlist->count_items() > 0 ) || ( ! $hide_zero_products_number && 0 === $wishlist->count_items() ) ) ) : ?>
				<span class="products_counter_number"><?php echo wp_kses_post( $wishlist->count_items() ); ?></span>
			<?php endif; ?>
			<?php if ( 'yes' === $show_text ) : ?>
				<span class="wishlist_products_counter_text"><?php echo wp_kses_post( $counter_text ); ?></span>
			<?php endif; ?>
			<?php if ( 'right' === $products_number_position && 'yes' === $show_counter && ( ( $wishlist->count_items() > 0 ) || ( ! $hide_zero_products_number && 0 === $wishlist->count_items() ) ) ) : ?>
				<span class="products_counter_number"><?php echo wp_kses_post( $wishlist->count_items() ); ?></span>
			<?php endif; ?>
		</a>
	<?php endif; ?>
	<?php if ( 'yes' === $show_products ) : ?>
		<div class="wlfmc_products_counter_wishlist <?php echo 'yes' === $dropdown_products ? 'wlfmc_products_counter_dropdown' : ''; ?>">
			<div class="wlfmct_wishlist_content d-flex flex-column gap-10">
				<?php if ( $wishlist && $wishlist->has_items() ) : ?>
					<?php if ( 'before' === $wishlist_link_position ) : ?>
						<a href="<?php echo esc_url( $wishlist_url ); ?>" class="wlfmc-view-wishlist-link button ">
							<?php echo wp_kses_post( $wishlist_link_title ); ?>
						</a>
					<?php endif; ?>
					<div class="wlfmc_mini_wishlist_list">
						<?php foreach ( $wishlist_items as $item ) : ?>
							<?php
							// phpcs:ignore Generic.Commenting.DocComment
							/**
							 * @var $item WLFMC_Wishlist_Item
							 */
							global $product;

							$product = $item->get_product();
							?>
							<?php if ( $product && $product->exists() ) : ?>
								<div id="wlfmc-row-<?php echo esc_attr( $item->get_product_id() ); ?>"
									data-row-id="<?php echo esc_attr( $item->get_product_id() ); ?>"
									class="d-flex gap-10 ">
									<a class="product-thumbnail"
									   href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item->get_product_id() ) ) ); ?>">
										<?php echo wp_kses_post( $product->get_image() ); ?>
									</a>
									<div class="max-100">
										<a class="product-name"
										   href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item->get_product_id() ) ) ); ?>">
											<?php echo wp_kses_post( apply_filters( 'woocommerce_in_cartproduct_obj_title', $product->get_title(), $product ) ); ?>
										</a>
										<div class="product-price price">
											<?php
											echo wp_kses_post( $item->get_formatted_product_price() );
											echo wp_kses_post( $item->get_price_variation() );
											?>
										</div>
									</div>

								</div>
							<?php endif; ?>
						<?php endforeach; ?>
					</div>
					<div class="total-products d-flex space-between ">
						<span><?php echo __('Total products:', 'wc-wlfmc-wishlist');?></span>
						<span><?php echo  esc_attr( $wishlist->count_items());?></span>
					</div>
					<?php if ( 'after' === $wishlist_link_position ) : ?>
						<a href="<?php echo esc_url( $wishlist_url ); ?>" class="wlfmc-view-wishlist-link button center-align">
							<?php echo wp_kses_post( $wishlist_link_title ); ?>
						</a>
					<?php endif; ?>
				<?php else : ?>

					<p class="wlfmc-wishlist-empty"><?php echo wp_kses_post( apply_filters( 'wlfmc_no_product_in_wishlist_message', $empty_wishlist_content, $wishlist ) ); ?></p>

				<?php endif; ?>

			</div>
		</div>
	<?php endif; ?>
</div>

