<?php
/**
 * Wishlist pages template; load template parts basing on the url
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.2.2
 */

/**
 * Template Variables:
 *
 * @var $form_action                   string from action
 * @var $template_part                 string Template part currently being loaded (manage)
 * @var $user_wishlists                WLFMC_WCWL_Wishlist[] Array of user wishlists
 * @var $fragment_options              array Array of items to use for fragment generation
 * @var $wishlist                      WLFMC_WCWL_Wishlist Current wishlist
 * @var $wishlist_items                array Array of items to show for current page
 * @var $wishlist_token                string Current wishlist token
 * @var $wishlist_id                   int Current wishlist id
 * @var $users_wishlists               array Array of current user wishlists
 * @var $pagination                    string yes/no
 * @var $per_page                      int Items per page
 * @var $current_page                  int Current page
 * @var $page_links                    array Array of page links
 * @var $is_user_owner                 bool Whether current user is wishlist owner
 * @var $additional_info               bool Whether to show Additional info textarea in Ask an estimate form
 * @var $items_show                    array Array of items show
 * @var $available_multi_wishlist      bool Whether multi wishlist is enabled and available
 * @var $no_interactions               bool
 * @var $share_enabled                 bool Whether share buttons should appear
 * @var $share_atts                    array Array of options; shows which share links should be shown
 * @var $share_items                   array Array of active share buttons
 * @var $login_notice                  bool Whether to show quest notice
 * @var $login_notice_content          string Quest notice content
 * @var $login_notice_buttons          array Array of quest notice buttons
 * @var $var                           array Array of attributes that needs to be sent to sub-template
 * @var $empty_wishlist_content        string string of no product in wishlist
 * @var $enable_actions                bool Whether All together Actions is enabled
 * @var $enable_all_add_to_cart        bool Whether All add to cart is enabled
 * @var $view_mode                     string wishlist view mode grid/list
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
} ?>

<form id="wlfmc-wishlist-form" action="<?php echo esc_attr( $form_action ); ?>" method="post"
	  class="wlfmc-wishlist-form wlfmc-wishlist-fragment"
	  data-fragment-options="<?php echo esc_attr( wp_json_encode( $fragment_options ) ); ?>">

	<?php if ( function_exists( 'wc_print_notices' ) ) {
		wc_print_notices();
	} ?>
	<?php if ( isset( $login_notice ) && true === $login_notice ) : ?>
		<div class="wlfmc_guest_notice_wrapper">
			<div class="wlfmc_guest_notice_content">
				<?php echo wp_kses_post( $login_notice_content ); ?>
			</div>
			<div class="wlfmc_guest_notice_buttons">
				<?php if ( $login_notice_buttons && is_array( $login_notice_buttons ) && ! empty( $login_notice_buttons ) ) : ?>
					<?php foreach ( $login_notice_buttons as $k => $button ) : ?>
						<?php
						switch ( $button['link'] ) {
							case 'signup':
								echo ! is_user_logged_in() ? '<a href="' . esc_url( wp_registration_url() ) . '" class="button wlfmc-btn wlfmc_btn_' . esc_attr( $k ) . '">' . esc_attr( $button['label'] ) . '</a>' : '';
								break;
							case 'login':
							case 'signup-login':
								echo ! is_user_logged_in() ? '<a href="' . esc_url( wp_login_url() ) . '" class="button  wlfmc-btn wlfmc_btn_' . esc_attr( $k ) . '">' . esc_attr( $button['label'] ) . '</a>' : '';
								break;
							case 'custom-link':
								echo trim( $button['custom-link'] ) !== '' ? '<a href="' . esc_url( $button['custom-link'] ) . '" rel="nofollow" class="wlfmc-btn wlfmc_btn_' . esc_attr( $k ) . '">' . esc_attr( $button['label'] ) . '</a>' : '';
								break;
						}
						?>
					<?php endforeach; ?>
				<?php endif; ?>
			</div>
		</div>
	<?php endif; ?>
	<div class="wlfmc_wishlist_table_wrapper">
		<table
			class="wlfmc_wishlist_table <?php echo wp_is_mobile() ? 'is_mobile' : ''; ?> view_mode_<?php echo esc_attr( $view_mode ); ?>"
			data-pagination="<?php echo esc_attr( $pagination ); ?>"
			data-per-page="<?php echo esc_attr( $per_page ); ?>"
			data-page="<?php echo esc_attr( $current_page ); ?>"
			data-id="<?php echo esc_attr( $wishlist_id ); ?>"
			data-token="<?php echo esc_attr( $wishlist_token ); ?>">

			<tbody class="wishlist-items-wrapper">
			<?php if ( $wishlist && $wishlist->has_items() ) : ?>
				<?php foreach ( $wishlist_items as $item ) : ?>
					<?php
					// phpcs:ignore Generic.Commenting.DocComment
					/**
					 * @var $item WLFMC_Wishlist_Item
					 */
					global $product;

					$product      = $item->get_product();
					$availability = $product->get_availability();
					$stock_status = isset( $availability['class'] ) ? $availability['class'] : false;
					?>
					<?php if ( $product && $product->exists() ) : ?>
						<tr id="wlfmc-row-<?php echo esc_attr( $item->get_product_id() ); ?>"
							data-row-id="<?php echo esc_attr( $item->get_product_id() ); ?>">
							<td class="first-column">
								<div class="d-flex gap-10 f-center-item">
									<?php if ( in_array( 'product-checkbox', $items_show ) ) : ?>
										<?php do_action( 'wlfmc_table_before_product_checkbox', $item, $wishlist ); ?>

										<label class="product-checkbox hide-on-grid-mode checkbox-label">
											<input type="checkbox" value="yes"
												   name="items[<?php echo esc_attr( $item->get_product_id() ); ?>][cb]">
											<span></span>
										</label>
										<?php do_action( 'wlfmc_table_after_product_checkbox', $item, $wishlist ); ?>

									<?php endif; ?>
									<?php if ( in_array( 'product-remove', $items_show ) && $wishlist->current_user_can( 'remove_from_wishlist' ) ) : ?>
										<?php do_action( 'wlfmc_table_before_product_remove', $item, $wishlist ); ?>

										<a href="<?php echo esc_url( add_query_arg( 'remove_from_wishlist', $item->get_product_id() ) ); ?>"
										   class="product-remove wlfmc_remove_from_wishlist"
										   title="<?php echo esc_html( apply_filters( 'wlfmc_remove_product_wishlist_message_title', __( 'Remove this product', 'wc-wlfmc-wishlist' ) ) ); ?>">×</a>

										<?php do_action( 'wlfmc_table_after_product_remove', $item, $wishlist ); ?>
									<?php endif; ?>

									<?php if ( in_array( 'product-thumbnail', $items_show ) ) : ?>
										<?php do_action( 'wlfmc_table_before_product_thumbnail', $item, $wishlist ); ?>

										<a class="product-thumbnail"
										   href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item->get_product_id() ) ) ); ?>">
											<?php echo wp_kses_post( $product->get_image() ); ?>
										</a>

										<?php do_action( 'wlfmc_table_after_product_thumbnail', $item, $wishlist ); ?>
									<?php endif; ?>

								</div>
							</td>
							<td class="center-column">
								<div class="d-flex flex-column gap-5">
									<?php if ( in_array( 'product-name', $items_show ) ) : ?>
										<?php do_action( 'wlfmc_table_before_product_name', $item, $wishlist ); ?>

										<a class="product-name"
										   href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item->get_product_id() ) ) ); ?>">
											<strong><?php echo wp_kses_post( apply_filters( 'woocommerce_in_cartproduct_obj_title', $product->get_title(), $product ) ); ?></strong>
										</a>

										<?php do_action( 'wlfmc_table_after_product_name', $item, $wishlist ); ?>
									<?php endif; ?>

									<?php if ( in_array( 'product-review', $items_show ) && $product->get_rating_count() && wc_review_ratings_enabled() ) : ?>
										<?php do_action( 'wlfmc_table_before_product_review', $item, $wishlist ); ?>
										<div class="product-review">
											<?php echo wc_get_rating_html( $product->get_average_rating() ); // WPCS: XSS ok.?>
										</div>
										<?php do_action( 'wlfmc_table_after_product_review', $item, $wishlist ); ?>
									<?php endif; ?>

									<?php if ( in_array( 'product-date-added', $items_show ) && $item->get_date_added() ) : ?>
										<!-- Date added -->
										<?php
										// translators: date added label: 1 date added.
										echo '<div class="product-date-added dateadded hide-on-list-mode">' . esc_html( sprintf( __( 'Added on: %s', 'wc-wlfmc-wishlist' ), $item->get_date_added_formatted() ) ) . '</div>';
										?>

									<?php endif; ?>

									<?php if ( in_array( 'product-variation', $items_show ) && $product->is_type( 'variation' ) ) : ?>
										<?php do_action( 'wlfmc_table_before_product_variation', $item, $wishlist ); ?>
										<div class="product-variation">
											<?php
											// phpcs:ignore Generic.Commenting.DocComment
											/**
											 * @var $product WC_Product_Variation
											 */
											echo wc_get_formatted_variation( $product ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
											?>
										</div>
										<?php do_action( 'wlfmc_table_after_product_variation', $item, $wishlist ); ?>
									<?php endif; ?>

									<?php if ( in_array( 'product-price', $items_show ) ) : ?>
										<?php do_action( 'wlfmc_table_before_product_price', $item, $wishlist ); ?>
										<div class="product-price price">
											<?php
											echo wp_kses_post( $item->get_formatted_product_price() );
											echo wp_kses_post( $item->get_price_variation() );
											?>
										</div>
										<?php do_action( 'wlfmc_table_after_product_price', $item, $wishlist ); ?>
									<?php endif; ?>

									<?php if ( in_array( 'product-stock-status', $items_show ) ) : ?>
										<?php do_action( 'wlfmc_table_before_product_stock', $item, $wishlist ); ?>
										<div class="product-stock-status">
											<?php
											$quantity = $product->get_stock_quantity();
											// translators: %s: Product Quantity.
											$instock = $quantity && $quantity < 10 ? '<span class="wishlist-left-stock">' . esc_html( apply_filters( 'wlfmc_left_stock_label', sprintf( __( '%s Left', 'wc-wlfmc-wishlist' ), $quantity ), $quantity ) ) . '</span>' : '<span class="wishlist-in-stock">' . esc_html( apply_filters( 'wlfmc_in_stock_label', '' ) ) . '</span>';
											echo 'out-of-stock' === $stock_status ? '<span class="wishlist-out-of-stock">' . esc_html( apply_filters( 'wlfmc_out_of_stock_label', __( 'Out of stock', 'wc-wlfmc-wishlist' ) ) ) . '</span>' : $instock; // @codingStandardsIgnoreLine.
											?>
										</div>
										<?php do_action( 'wlfmc_table_after_product_stock', $item, $wishlist ); ?>
									<?php endif; ?>
								</div>
							</td>
							<td class="last-column">
								<div class="d-flex flex-column gap-5">
									<div class="d-flex gap-5 f-center-item">
										<?php if ( in_array( 'product-checkbox', $items_show ) ) : ?>
											<?php do_action( 'wlfmc_table_before_product_checkbox', $item, $wishlist ); ?>

											<label class="product-checkbox hide-on-list-mode checkbox-label">
												<input type="checkbox" value="yes"
													   name="items[<?php echo esc_attr( $item->get_product_id() ); ?>][cb]">
												<span></span>
											</label>
											<?php do_action( 'wlfmc_table_after_product_checkbox', $item, $wishlist ); ?>

										<?php endif; ?>
										<?php if ( in_array( 'product-add-to-cart', $items_show ) ) : ?>
											<?php do_action( 'wlfmc_table_before_product_cart', $item, $wishlist ); ?>


											<?php do_action( 'wlfmc_table_product_before_add_to_cart', $item, $wishlist ); ?>

											<!-- Add to cart button -->

											<?php woocommerce_template_loop_add_to_cart( array( 'quantity' => $item->get_quantity() ) ); ?>

											<?php do_action( 'wlfmc_table_product_after_add_to_cart', $item, $wishlist ); ?>
										<?php endif; ?>
										<?php if ( in_array( 'product-quantity', $items_show ) && ! $no_interactions && $wishlist->current_user_can( 'update_quantity' ) ) : ?>

											<?php do_action( 'wlfmc_table_before_product_quantity', $item, $wishlist ); ?>

											<?php
											woocommerce_quantity_input( array(
												'input_name'  => 'items[' . $item->get_product_id() . '][quantity]',
												'input_value' => $item->get_quantity()
											) );
											?>
											<?php do_action( 'wlfmc_table_after_product_quantity', $item, $wishlist ); ?>

										<?php endif; ?>
									</div>
									<?php if ( in_array( 'product-date-added', $items_show ) && $item->get_date_added() ) : ?>
										<!-- Date added -->
										<?php
										// translators: date added label: 1 date added.
										echo '<div class="product-date-added dateadded hide-on-grid-mode">' . esc_html( sprintf( __( 'Added on: %s', 'wc-wlfmc-wishlist' ), $item->get_date_added_formatted() ) ) . '</div>';
										?>

									<?php endif; ?>

								</div>
							</td>

						</tr>
					<?php endif; ?>
				<?php endforeach; ?>
			<?php else : ?>
				<tr>
					<td colspan="3"
						class="wishlist-empty"><?php echo wp_kses_post( apply_filters( 'wlfmc_no_product_in_wishlist_message', $empty_wishlist_content, $wishlist ) ); ?></td>
				</tr>
			<?php endif; ?>
			</tbody>
			<tfoot class="wlfmc_wishlist_footer">
			<?php if ( ! empty( $page_links ) ) : ?>
				<tr class="pagination-row wishlist-pagination">
					<td colspan="3">
						<nav class="woocommerce-pagination"><?php echo wp_kses_post( $page_links ); ?></nav>
					</td>
				</tr>
			<?php endif; ?>
			<?php if ( $wishlist && $wishlist->has_items() && ( $enable_actions || $enable_all_add_to_cart ) ): ?>
				<tr>
					<td colspan="3" class="with-border-top">
						<div class="action-wrapper space-between d-flex f-wrap gap-10">
							<?php if ( $enable_actions ): ?>
								<!-- Bulk actions form -->
								<div class="wlfmc_wishlist_bulk_action d-flex f-center-item gap-5">
									<?php if ( in_array( 'product-checkbox', $items_show ) ) : ?>
										<label class="checkbox-label">
											<input type="checkbox" value="" name="" id="bulk_add_to_cart"/>
											<span></span>
										</label>
									<?php endif; ?>
									<select name="bulk_actions" id="bulk_actions">
										<option value=""><?php esc_html_e( 'Actions', 'wc-wlfmc-wishlist' ); ?></option>
										<option
											value="add_to_cart"><?php esc_html_e( 'Add to cart', 'wc-wlfmc-wishlist' ); ?></option>

										<?php if ( $wishlist && $wishlist->has_items() && $wishlist->current_user_can( 'remove_from_wishlist' ) ) : ?>
											<option
												value="delete"><?php esc_html_e( 'Remove', 'wc-wlfmc-wishlist' ); ?></option>
										<?php endif; ?>
									</select>
									<input type="submit" class="apply-btn button"
										   name="apply_bulk_actions"
										   value="<?php esc_html_e( 'Apply', 'wc-wlfmc-wishlist' ); ?>"/>
								</div>
							<?php endif; ?>
							<?php if ( $enable_all_add_to_cart ): ?>
								<input type="submit" class="add-all-to-cart-btn button" name="add_all_to_cart"
									   value="<?php esc_html_e( 'Add all to cart', 'wc-wlfmc-wishlist' ); ?>"/>
							<?php endif; ?>
						</div>
					</td>
				</tr>
			<?php endif; ?>
			<?php if ( $share_enabled ) : ?>
				<tr>
					<td colspan="3" class="with-border-top">
						<div class="share-wrapper">
							<!-- Sharing section -->
							<?php if ( is_array( $share_items ) && ! empty( $share_items ) ) : ?>
								<div class="wlfmc-share d-flex justify-center f-center-item">
									<strong
										class="wlfmc-share-title"><?php esc_attr_e( 'Share on:', 'wc-wlfmc-wishlist' ); ?></strong>
									<ul>
										<?php foreach ( $share_items as $k => $share_item ) : ?>
											<?php if ( 'facebook' === $share_item ) : ?>
												<li class="share-button">
													<a target="_blank" rel="noopener"
													   class="facebook  wlfmc-tooltip wlfmc-tooltip-top default-style"
													   href="https://www.facebook.com/sharer.php?u=<?php echo rawurlencode( $share_atts['share_link_url'] ); ?>&p[title]=<?php echo esc_attr( $share_atts['share_socials_title'] ); ?>"
													   data-tooltip-type="default"
													   data-tooltip-text="<?php esc_html_e( 'Share on facebook', 'wc-wlfmc-wishlist' ); ?>">
														<?php echo $share_atts['share_facebook_icon'] ? wp_kses_post( $share_atts['share_facebook_icon'] ) : esc_html__( 'Facebook', 'wc-wlfmc-wishlist' ); ?>
													</a>
												</li>
											<?php endif; ?>

											<?php if ( 'twitter' === $share_item ) : ?>
												<li class="share-button">
													<a target="_blank" rel="noopener"
													   class="twitter  wlfmc-tooltip wlfmc-tooltip-top default-style"
													   href="https://twitter.com/share?url=<?php echo rawurlencode( $share_atts['share_link_url'] ); ?>&amp;text=<?php echo esc_attr( $share_atts['share_socials_text'] ); ?>"
													   data-tooltip-type="default"
													   data-tooltip-text="<?php esc_html_e( 'Share on twitter', 'wc-wlfmc-wishlist' ); ?>">
														<?php echo $share_atts['share_twitter_icon'] ? wp_kses_post( $share_atts['share_twitter_icon'] ) : esc_html__( 'Twitter', 'wc-wlfmc-wishlist' ); ?>
													</a>
												</li>
											<?php endif; ?>

											<?php if ( 'messenger' === $share_item ) : ?>
												<li class="share-button">
													<a target="_blank" rel="noopener"
													   class="messenger  wlfmc-tooltip wlfmc-tooltip-top default-style"
													   href="fb-messenger://share/?link=<?php echo rawurlencode( $share_atts['share_link_url'] ); ?>"
													   data-tooltip-type="default"
													   data-tooltip-text="<?php esc_html_e( 'Share with messenger', 'wc-wlfmc-wishlist' ); ?>">
														<?php echo $share_atts['share_messenger_icon'] ? wp_kses_post( $share_atts['share_messenger_icon'] ) : esc_html__( 'Messenger', 'wc-wlfmc-wishlist' ); ?>
													</a>
												</li>
											<?php endif; ?>

											<?php if ( 'email' === $share_item ) : ?>
												<li class="share-button">
													<a class="email  wlfmc-tooltip wlfmc-tooltip-top default-style"
													   href="mailto:?subject=<?php echo esc_attr( apply_filters( 'wlfmc_email_share_subject', $share_atts['share_socials_title'] ) ); ?>&amp;body=<?php echo esc_attr( apply_filters( 'wlfmc_email_share_body', rawurlencode( $share_atts['share_link_url'] ) ) ); ?>&amp;title=<?php echo esc_attr( $share_atts['share_socials_title'] ); ?>"
													   data-tooltip-type="default"
													   data-tooltip-text="<?php esc_html_e( 'Share with email', 'wc-wlfmc-wishlist' ); ?>">
														<?php echo $share_atts['share_email_icon'] ? wp_kses_post( $share_atts['share_email_icon'] ) : esc_html__( 'Email', 'wc-wlfmc-wishlist' ); ?>
													</a>
												</li>
											<?php endif; ?>

											<?php if ( 'whatsapp' === $share_item ) : ?>
												<li class="share-button">
													<a class="whatsapp  wlfmc-tooltip wlfmc-tooltip-top default-style "
													   href="<?php echo esc_url( $share_atts['share_whatsapp_url'] ); ?>"
													   data-action="share/whatsapp/share" target="_blank" rel="noopener"
													   data-tooltip-type="default"
													   data-tooltip-text="<?php esc_html_e( 'Share on whatsApp', 'wc-wlfmc-wishlist' ); ?>">
														<?php echo $share_atts['share_whatsapp_icon'] ? wp_kses_post( $share_atts['share_whatsapp_icon'] ) : esc_html__( 'Whatsapp', 'wc-wlfmc-wishlist' ); ?>
													</a>
												</li>
											<?php endif; ?>

											<?php if ( 'telegram' === $share_item ) : ?>
												<li class="share-button">
													<a class="telegram  wlfmc-tooltip wlfmc-tooltip-top default-style"
													   href="<?php echo esc_url( $share_atts['share_telegram_url'] ); ?>"
													   target="_blank" rel="noopener"
													   data-tooltip-type="default"
													   data-tooltip-text="<?php esc_html_e( 'Share on Telegram', 'wc-wlfmc-wishlist' ); ?>">
														<?php echo $share_atts['share_telegram_icon'] ? wp_kses_post( $share_atts['share_telegram_icon'] ) : esc_html__( 'Telegram', 'wc-wlfmc-wishlist' ); ?>
													</a>
												</li>
											<?php endif; ?>
											<?php if ( 'copy' === $share_item ) : ?>
												<li class="share-button">
													<a class="copy-link-trigger wlfmc-tooltip wlfmc-tooltip-top default-style"
													   data-tooltip-type="default"
													   data-tooltip-text="<?php esc_html_e( 'Click to copy the link', 'wc-wlfmc-wishlist' ); ?>"
													   href="<?php echo esc_url( $share_atts['share_link_url'] ); ?>"><?php echo wp_kses_post( $share_atts['share_copy_icon'] ); ?></a>
												</li>
											<?php endif; ?>
										<?php endforeach; ?>
									</ul>


								</div>
							<?php endif; ?>
						</div>
					</td>
				</tr>
			<?php endif; ?>
			</tfoot>
		</table>
	</div>

	<?php wp_nonce_field( 'wlfmc_edit_wishlist_action', 'wlfmc_edit_wishlist' ); ?>
	<input type="hidden" value="<?php echo esc_attr( $wishlist_token ); ?>" name="wishlist_id" id="wishlist_id">

</form>
